Compare commits

...

165 Commits

Author SHA1 Message Date
Leona Maroni
e56e0beed4 25.11 is Xantusia 2025-05-16 19:21:55 +02:00
Nikolay Korotkiy
f575a9791f telescope: 0.10.1 → 0.11 (#406082) 2025-05-16 21:20:25 +04:00
nixpkgs-merge-bot[bot]
9d2f5e3e71 tbtools: 0.5.0 -> 0.6.0 (#407634)
Co-authored-by: felixsinger <felixsinger@users.noreply.github.com>
2025-05-16 17:17:59 +00:00
nixpkgs-merge-bot[bot]
918414e589 komga: 1.21.2 -> 1.21.3 (#407545)
Co-authored-by: tebriel <tebriel@users.noreply.github.com>
2025-05-16 17:16:11 +00:00
Lucie
b965e4c283 rocqPackages.rocq-elpi: 2.5.1 -> 2.5.2 2025-05-16 18:34:47 +02:00
nixpkgs-merge-bot[bot]
74822229d7 snowflake-cli: 3.7.1 -> 3.7.2 (#407472)
Co-authored-by: VTimofeenko <VTimofeenko@users.noreply.github.com>
2025-05-16 16:30:12 +00:00
Fabian Affolter
41099deff2 python312Packages.mypy-boto3-*: updates (#407103) 2025-05-16 18:16:15 +02:00
nixpkgs-merge-bot[bot]
a894151192 orchard: 0.33.0 -> 0.33.2 (#407437)
Co-authored-by: techknowlogick <hello@techknowlogick.com>
2025-05-16 16:12:46 +00:00
nixpkgs-merge-bot[bot]
62b33379c2 msolve: 0.7.5 -> 0.8.0 (#407626)
Co-authored-by: wegank <wegank@users.noreply.github.com>
2025-05-16 15:57:44 +00:00
Alois Wohlschlager
62536dc831 lixPackageSets.git: init at 2.94.0-pre-20250509_dcb0a97000d5 2025-05-16 17:55:05 +02:00
Alois Wohlschlager
f36204cb00 lixPackageSets.lix_2_93: init at 2.93.0 2025-05-16 17:55:05 +02:00
Alois Wohlschlager
9685bc5a05 lixPackageSets.*.lix: test the correct Lix in passthru.tests
Previously always the top-level lix package would be used, which is obviously
not what we want.
2025-05-16 17:55:05 +02:00
Alois Wohlschlager
32be3c655c lixPackageSets: support splicing 2025-05-16 17:55:05 +02:00
Pol Dellaiera
7b7a9a6a14 proto: 0.48.1 -> 0.49.1 (#407569) 2025-05-16 15:44:23 +00:00
Pol Dellaiera
65799e35e6 imager: 4.4-01 -> 4.5-01 (#407584) 2025-05-16 15:43:09 +00:00
Pol Dellaiera
b7b03f94e9 latexminted: 0.5.1 -> 0.6.0 (#407586) 2025-05-16 15:37:33 +00:00
isabel
6dc8edf1f5 nixos/minecraft-server: update outdated links (#405554) 2025-05-16 16:30:39 +01:00
dotlambda
cc9b9356ac immich: use our own esbuild (#404977) 2025-05-16 08:28:03 -07:00
Pol Dellaiera
bfc2953626 treefmt: 2.2.1 -> 2.3.0 (#407639) 2025-05-16 15:24:34 +00:00
Aleksana
48b2ee79a8 finalmouse-udev-rules: init package (#404038) 2025-05-16 23:19:51 +08:00
Yureka
038e56f4b4 lixPackageSets.latest.colmena: init (#407571)
Similar to nix-fast-build, this provides a version of colmena using Lix
2025-05-16 17:17:30 +02:00
7c6f434c
27628750ba gajim: 2.1.1 → 2.2.0; pythonPackages.nbxmpp: 6.1.1 → 6.2.0 (#407554) 2025-05-16 15:05:39 +00:00
Wolfgang Walther
f85f13488d qsv: remove uncenter from maintainers (#407638) 2025-05-16 15:04:58 +00:00
Adam C. Stephens
dc8fc51442 tailwindcss_4: 4.1.6 -> 4.1.7 (#407549) 2025-05-16 11:00:37 -04:00
Emilia
24234fde08 finalmouse-udev-rules: init at 0-unstable-2025-05-05 2025-05-16 16:59:55 +02:00
Leona Maroni
7ebb37aee6 nixos/doc/rl-2505: add nixos wiki section (#407470) 2025-05-16 16:57:57 +02:00
Tom Herbers
590a3fac9a bird3: 3.0.2 -> 3.1.1 (#407612)
Changelog: https://gitlab.nic.cz/labs/bird/-/blob/v3.1.1/NEWS

This reverts the downgrade to the 3.0.x track (#404140) because the
missing patches which lead to the revert have been applied
according to the Changelog.
2025-05-16 16:28:40 +02:00
Brian McGee
4d60c970ae treefmt: 2.2.1 -> 2.3.0 2025-05-16 15:19:37 +01:00
Pol Dellaiera
04d6d96682 amazon-q-cli: 1.9.1 -> 1.10.0 (#407535) 2025-05-16 14:19:24 +00:00
uncenter
b8c415e300 qsv: remove uncenter from maintainers 2025-05-16 10:17:44 -04:00
Pol Dellaiera
694c7a734f uv: 0.7.3 -> 0.7.4 (#407414) 2025-05-16 14:15:00 +00:00
Aleksana
030e0581bb hypercore: init at 11.7.0 (#403381) 2025-05-16 22:12:01 +08:00
K900
5ddf398c7d gamescope: 3.16.7 -> 3.16.9 (#407635) 2025-05-16 17:09:47 +03:00
James Ward
705f0cab4a amazon-q-cli: 1.9.1 -> 1.10.0 2025-05-16 08:05:17 -06:00
Gliczy
a347e8607a gamescope: 3.16.7 -> 3.16.9 2025-05-16 15:59:07 +02:00
nixpkgs-merge-bot[bot]
71192dcdac joplin-desktop: 3.2.13 -> 3.3.12 (#407025)
Co-authored-by: yajo <yajo@users.noreply.github.com>
2025-05-16 13:53:33 +00:00
nixpkgs-merge-bot[bot]
368b6c52de quarkus: 3.21.4 -> 3.22.2 (#406354)
Co-authored-by: Vinetos <Vinetos@users.noreply.github.com>
2025-05-16 13:53:26 +00:00
R. Ryantm
8a82f7fbc8 tbtools: 0.5.0 -> 0.6.0 2025-05-16 13:51:37 +00:00
Yohann Boniface
11f1ef64f2 teams/sdl: add members, adopt and drop packages (#407049) 2025-05-16 15:49:17 +02:00
Nikolay Korotkiy
12d2900b90 trayscale: 0.14.3 → 0.16.0 (#406154) 2025-05-16 17:44:30 +04:00
Jonas Heinrich
88e7610358 circleci-cli: 0.1.31543 -> 0.1.31632 (#401465) 2025-05-16 15:43:47 +02:00
Austin Horstman
0e6363bc97 yaziPlugins.nord: init at 0-unstable-2025-05-14 (#407170) 2025-05-16 08:41:44 -05:00
Pol Dellaiera
b9d68cd63a cloudflared: 2025.4.0 -> 2025.5.0 (#407543) 2025-05-16 13:40:38 +00:00
Kristoffer Plagborg Bak Sørensen
d8eac90d7e tuistash: init at 0.7.1 (#405939) 2025-05-16 21:40:25 +08:00
Aleksana
538723cee1 goctl: init at 1.8.3 (#407314) 2025-05-16 21:39:28 +08:00
Aleksana
bd13acdd67 mini-redis: init at 0.4.1 (#405626) 2025-05-16 21:38:44 +08:00
Pol Dellaiera
f2fa709998 screen: 5.0.0 -> 5.0.1 (#407576) 2025-05-16 13:38:28 +00:00
Aleksana
18a63d143f uwu-colors: init at 0.4.0 (#407421) 2025-05-16 21:37:56 +08:00
Aleksana
0488dafa81 wfview: init at 2.10, {libsForQt5,kdePackages}.qcustomplot: init at 2.1.1 (#404699) 2025-05-16 21:37:32 +08:00
Aleksana
5599f0b19b rquickshare: fix darwin build (#407529) 2025-05-16 21:36:31 +08:00
Austin Horstman
d0658f2a6b yaziPlugins.restore: 25.2.7-unstable-2025-04-04 -> 25.2.7-unstable-2025-04-24 (#407565) 2025-05-16 08:35:34 -05:00
jopejoe1
46c702a1ec python3Packages.django-pglock: 1.7.1 -> 1.7.2 (#407621) 2025-05-16 15:35:22 +02:00
Pol Dellaiera
c88a00199d vscode-extensions.13xforever.language-x86-64-assembly: 3.1.4 -> 3.1.5 (#407355) 2025-05-16 13:33:54 +00:00
Pol Dellaiera
f5f90ce3d5 vscode-extensions.42crunch.vscode-openapi: 4.33.1 -> 4.33.2 (#407378) 2025-05-16 13:33:42 +00:00
sehe
3f34865d8f roon-server: 2.50.1528 -> 2.51.1534
https://community.roonlabs.com/t/roon-2-51-and-arc-1-66-are-live/299274
2025-05-16 06:33:02 -07:00
sehe
19e2a9ec00 roon-server: 2.49.1525 -> 2.50.1528
https://community.roonlabs.com/t/roon-2-50-build-1528-is-live/297986
2025-05-16 06:33:02 -07:00
Pol Dellaiera
93723a35f1 cherry-studio: 1.3.2 -> 1.3.4 (#407401) 2025-05-16 13:32:21 +00:00
Aleksana
0914c5a769 mkspiffs: remove redundant doCheck attribute (#407624) 2025-05-16 21:32:06 +08:00
Pol Dellaiera
bb8755aef3 ruff: 0.11.9 -> 0.11.10 (#407438) 2025-05-16 13:30:44 +00:00
Pol Dellaiera
8c63c073f9 opencode: 0.0.34 -> 0.0.46 (#407439) 2025-05-16 13:30:31 +00:00
Pol Dellaiera
a30220367f windsurf: 1.8.2 -> 1.9.0 (#407468) 2025-05-16 13:30:09 +00:00
Qiming Chu
bc33919e63 haskellPackages.sv2v: fix build and enable
* Jailbreak sv2v package to relax too strict bounds on base <4.19
* Remove sv2v from broken packages list
* Remove hydraPlatforms and broken flags to enable building

Signed-off-by: Qiming Chu <cchuqiming@gmail.com>
2025-05-16 15:29:26 +02:00
Pol Dellaiera
5943856028 vscode-extensions.rooveterinaryinc.roo-cline: 3.16.5 -> 3.17.1 (#407488) 2025-05-16 13:29:17 +00:00
Pol Dellaiera
537084d76e vscode-extensions.redhat.java: 1.41.2025031208 -> 1.42.0 (#407517) 2025-05-16 13:29:04 +00:00
R. Ryantm
1fbaaa0a4c msolve: 0.7.5 -> 0.8.0 2025-05-16 13:24:15 +00:00
Stefan Frijters
8e9d24863d mkspiffs: remove redundant doCheck attribute 2025-05-16 15:13:59 +02:00
Austin Horstman
8e0ab7c192 vimPlugins.GPTModels-nvim: init at 2025-05-15 (#407458) 2025-05-16 08:11:36 -05:00
Austin Horstman
7ddb07a4e0 vimPlugins.neogit: update on 2025-05-16 (#407561) 2025-05-16 08:10:52 -05:00
Sandro
c0cd90d343 nixos/etc: remove rogue continue (#399915) 2025-05-16 15:08:17 +02:00
Maximilian Bosch
f88f619b20 Merge: nextcloud: 30.0.10 -> 30.0.11, 31.0.4 -> 31.0.5 (#407351) 2025-05-16 15:03:36 +02:00
R. Ryantm
a4f0eb2ef1 python3Packages.django-pglock: 1.7.1 -> 1.7.2 2025-05-16 12:58:29 +00:00
Adam C. Stephens
47dec1cd02 microsoft-edge: 136.0.3240.64 -> 136.0.3240.76 (#407614) 2025-05-16 08:52:10 -04:00
Adam C. Stephens
85c70ac44f maintainers: remove zanculmarktum
https://github.com/NixOS/nixpkgs/pull/402413#issuecomment-2886577999
2025-05-16 08:46:27 -04:00
Adam C. Stephens
75500d4f1a microsoft-edge: 136.0.3240.64 -> 136.0.3240.76 2025-05-16 12:37:04 +00:00
Adam C. Stephens
d25ea431bd Headscale service wait before restart (#400053) 2025-05-16 08:30:08 -04:00
Leona Maroni
cff416fbe7 scaphandre: mark as broken (#407408) 2025-05-16 14:28:07 +02:00
R. Ryantm
3be455e0d8 amiri: 1.001 -> 1.002 2025-05-16 14:23:53 +02:00
nixpkgs-merge-bot[bot]
55625873ca pocketbase: 0.27.2 -> 0.28.1 (#407603)
Co-authored-by: thilobillerbeck <thilo.billerbeck@officerent.de>
2025-05-16 12:14:13 +00:00
Adam C. Stephens
60b261bb61 microsoft-edge: 135.0.3179.85 -> 136.0.3240.64 (#402413) 2025-05-16 08:10:11 -04:00
Jan Tojnar
c5c594d575 Merge gnomeExtensions.guillotine: 25 -> 26 (#398399) 2025-05-16 14:02:56 +02:00
Peder Bergebakken Sundt
ca86336a1d teams/sdl: add members 2025-05-16 14:01:06 +02:00
Peder Bergebakken Sundt
688a91d4b0 treewide: add and remove teams.sdl from meta.teams 2025-05-16 14:01:06 +02:00
R. Ryantm
55d96e89f9 pocketbase: 0.27.2 -> 0.28.1 2025-05-16 11:52:24 +00:00
Nikolay Korotkiy
f777a743bb paho-mqtt-cpp: 1.5.2 -> 1.5.3 (#407551) 2025-05-16 15:35:47 +04:00
Peder Bergebakken Sundt
a901f48212 flexget: 3.15.38 -> 3.15.42 (#407445) 2025-05-16 13:34:04 +02:00
Yaya
b288842ca9 pocket-casts: 0.10.2 -> 0.10.3
https://github.com/FelicianoTech/pocket-casts-desktop-app/compare/v0.10.2...v0.10.3
2025-05-16 13:28:54 +02:00
Daniel Schaefer
6b65937684 freeplane: 1.12.8 -> 1.12.10 (#406834) 2025-05-16 19:13:51 +08:00
Jon Seager
09cbcfa99c google-chrome: 136.0.7103.59 -> 136.0.7103.113 2025-05-16 16:43:03 +05:30
Peder Bergebakken Sundt
5847563213 python313Packages.hdf5plugin: 5.0.0 -> 5.1.0 (#406712) 2025-05-16 13:03:51 +02:00
José Romildo
39cd857722 latexminted: 0.5.1 -> 0.6.0 2025-05-16 07:50:54 -03:00
nixpkgs-merge-bot[bot]
782f6df454 copilot-language-server: 1.312.0 -> 1.322.0 (#407573)
Co-authored-by: arunoruto <arunoruto@users.noreply.github.com>
2025-05-16 10:49:33 +00:00
Sébastien Maret
12a58dad51 imager: 4.4-01 -> 4.5-01 2025-05-16 12:36:36 +02:00
nomaterials
9a15303309 mini-redis: init at 0.4.1
mini-redis: init at 0.4.1

mini-redis: cleanup
2025-05-16 12:08:47 +02:00
Thomas Gerbet
0932102402 screen: 5.0.0 -> 5.0.1
Fixes CVE-2025-46805, CVE-2025-46804, CVE-2025-46803, CVE-2025-46802,
CVE-2025-23395.

https://lists.gnu.org/archive/html/screen-devel/2025-05/msg00008.html
2025-05-16 12:05:09 +02:00
emaryn
3a6d283e95 cherry-studio: 1.3.2 -> 1.3.4 2025-05-16 10:04:54 +00:00
R. Ryantm
b17dd69dc3 copilot-language-server: 1.312.0 -> 1.322.0 2025-05-16 09:53:30 +00:00
R. Ryantm
ebce80f8d8 proto: 0.48.1 -> 0.49.1 2025-05-16 09:28:23 +00:00
R. Ryantm
6c12d612fb yaziPlugins.restore: 25.2.7-unstable-2025-04-04 -> 25.2.7-unstable-2025-04-24 2025-05-16 08:59:51 +00:00
Cryolitia PukNgae
9d500f45ea wfview: init at 2.10 2025-05-16 16:55:14 +08:00
Cryolitia PukNgae
1a270ec36c {libsForQt5,kdePackages}.qcustomplot: init at 2.1.1 2025-05-16 16:54:38 +08:00
Firelight Flagboy
787041911d vimPlugins.neogit: update on 2025-05-16 2025-05-16 10:51:52 +02:00
kira malinova
90b17462ed uwu-colors: init at 0.4.0 2025-05-16 11:38:50 +03:00
·𐑑𐑴𐑕𐑑𐑩𐑤
457db0169b gajim: 2.1.1 → 2.2.0 2025-05-16 15:35:23 +07:00
·𐑑𐑴𐑕𐑑𐑩𐑤
02f9d2f427 pythonPackages.nbxmpp: 6.1.1 → 6.2.0 2025-05-16 15:35:23 +07:00
Kalle Ahlström
bedc1f26c3 doc/tauri: move wrapGAppsHook4 to only be included in linux builds 2025-05-16 10:20:40 +02:00
Kalle Ahlström
3aedf37e03 rquickshare: fix darwin build 2025-05-16 10:20:40 +02:00
Casey Link
3a5d8b808d tailwindcss_4: 4.1.6 -> 4.1.7 2025-05-16 09:57:19 +02:00
R. Ryantm
e3b178c81e paho-mqtt-cpp: 1.5.2 -> 1.5.3 2025-05-16 07:51:22 +00:00
Nikolay Korotkiy
fd33196b5d telescope: modernize 2025-05-16 11:49:21 +04:00
R. Ryantm
e342786ef7 komga: 1.21.2 -> 1.21.3 2025-05-16 07:23:44 +00:00
Arsenii Zorin
1c4eeef58a cloudflared: 2025.4.0 -> 2025.5.0 2025-05-16 10:11:53 +03:00
George
8e7e2e274c goctl: init at 1.8.3
Update pkgs/by-name/go/go-zero-cli/package.nix

Co-authored-by: Aleksana <alexander.huang.y@gmail.com>

goctl: init at 1.8.3
2025-05-16 04:00:54 +00:00
R. Ryantm
639b31e678 vscode-extensions.redhat.java: 1.41.2025031208 -> 1.42.0 2025-05-16 03:27:18 +00:00
R. Ryantm
118799a749 vscode-extensions.rooveterinaryinc.roo-cline: 3.16.5 -> 3.17.1 2025-05-16 00:29:00 +00:00
Seth Flynn
07daaf28e6 nixos/doc/rl-2505: add nixos wiki section 2025-05-15 19:02:49 -04:00
R. Ryantm
3025b603b9 snowflake-cli: 3.7.1 -> 3.7.2 2025-05-15 22:53:33 +00:00
Sarah Clark
b1bd9c3f6a windsurf: 1.8.2 -> 1.9.0
changelog: https://windsurf.com/changelog
2025-05-15 15:30:16 -07:00
Gutyina Gergő
2ce3372ba2 vimPlugins.GPTModels-nvim: init at 2025-05-15 2025-05-15 22:19:19 +02:00
R. Ryantm
4effb092f2 flexget: 3.15.38 -> 3.15.42 2025-05-15 19:38:05 +00:00
Benjamin Sparks
59b14628e2 ruff: 0.11.9 -> 0.11.10 2025-05-15 19:24:07 +00:00
R. Ryantm
e3f297b2b8 opencode: 0.0.34 -> 0.0.46 2025-05-15 19:16:52 +00:00
R. Ryantm
e66b8dd8b2 orchard: 0.33.0 -> 0.33.2 2025-05-15 19:15:38 +00:00
Sizhe Zhao
a880c7950f uv: 0.7.3 -> 0.7.4 2025-05-16 02:05:32 +08:00
Sizhe Zhao
4a2cdbf067 uv: add prince213 to maintainers 2025-05-16 02:02:07 +08:00
teutat3s
b571f320ef scaphandre: mark as broken 2025-05-15 19:49:01 +02:00
Fabian Affolter
049eac130d python313Packages.boto3-stubs: 1.38.15 -> 1.38.16 2025-05-15 17:29:34 +02:00
Fabian Affolter
d54a7c4478 python313Packages.botocore-stubs: 1.38.15 -> 1.38.16 2025-05-15 17:29:31 +02:00
Fabian Affolter
ad9ee74656 python312Packages.mypy-boto3-mediaconvert: 1.38.9 -> 1.38.16 2025-05-15 17:28:56 +02:00
Fabian Affolter
5f4bde0255 python312Packages.mypy-boto3-logs: 1.38.13 -> 1.38.16 2025-05-15 17:28:52 +02:00
Fabian Affolter
3a6abc4711 python312Packages.mypy-boto3-firehose: 1.38.0 -> 1.38.16 2025-05-15 17:28:34 +02:00
Fabian Affolter
407dc8d806 python312Packages.mypy-boto3-cognito-idp: 1.38.0 -> 1.38.16 2025-05-15 17:28:20 +02:00
Fabian Affolter
c95302ca89 python313Packages.boto3-stubs: 1.38.13 -> 1.38.15 2025-05-15 17:28:02 +02:00
Fabian Affolter
ac7dbf0bb8 python313Packages.botocore-stubs: 1.38.13 -> 1.38.15 2025-05-15 17:28:01 +02:00
Fabian Affolter
c87f323b33 python312Packages.mypy-boto3-sagemaker: 1.38.11 -> 1.38.14 2025-05-15 17:28:01 +02:00
Fabian Affolter
284f51cd63 python312Packages.mypy-boto3-s3control: 1.38.0 -> 1.38.14 2025-05-15 17:28:01 +02:00
Fabian Affolter
6e4ee16675 python312Packages.mypy-boto3-mediatailor: 1.38.0 -> 1.38.14 2025-05-15 17:28:01 +02:00
Fabian Affolter
2e0c81d6bc python312Packages.mypy-boto3-medialive: 1.38.11 -> 1.38.14 2025-05-15 17:28:01 +02:00
Fabian Affolter
8d43db0f7c python312Packages.mypy-boto3-license-manager: 1.38.0 -> 1.38.15 2025-05-15 17:28:01 +02:00
Fabian Affolter
2d587c18d6 python312Packages.mypy-boto3-iam: 1.38.0 -> 1.38.14 2025-05-15 17:28:01 +02:00
Fabian Affolter
17d3f99c59 python312Packages.mypy-boto3-ecs: 1.38.9 -> 1.38.15 2025-05-15 17:28:01 +02:00
Fabian Affolter
e32301dca2 python312Packages.mypy-boto3-ec2: 1.38.12 -> 1.38.14 2025-05-15 17:28:01 +02:00
Fabian Affolter
65061a2c0a python312Packages.mypy-boto3-controltower: 1.38.0 -> 1.38.15 2025-05-15 17:28:01 +02:00
Amadej Kastelic
09f2af8d42 freeplane: 1.12.8 -> 1.12.10
https://www.freeplane.org/info/history/history_en.txt
2025-05-15 17:03:50 +02:00
R. Ryantm
b0d09f11e9 vscode-extensions.42crunch.vscode-openapi: 4.33.1 -> 4.33.2 2025-05-15 14:47:03 +00:00
goodylove
a580c9b1b2 hypercore: init at 11.7.0 2025-05-15 14:22:44 +01:00
R. Ryantm
07cbe2b8c6 vscode-extensions.13xforever.language-x86-64-assembly: 3.1.4 -> 3.1.5 2025-05-15 13:19:21 +00:00
Maximilian Bosch
292a46f1e0 nextcloudPackages: update 2025-05-15 15:09:29 +02:00
Maximilian Bosch
e6a91e9019 nextcloud31: 31.0.4 -> 31.0.5
ChangeLog: https://github.com/nextcloud/server/releases/tag/v31.0.5
2025-05-15 15:05:09 +02:00
Maximilian Bosch
a726df9405 nextcloud30: 30.0.10 -> 30.0.11
ChangeLog: https://github.com/nextcloud/server/releases/tag/v30.0.11
2025-05-15 15:04:44 +02:00
Yifei Sun
c017114e83 yaziPlugins.nord: init at 0-unstable-2025-05-14 2025-05-14 18:19:49 -04:00
R. Ryantm
1511f9a1fb joplin-desktop: 3.2.13 -> 3.3.12 2025-05-14 13:44:56 +00:00
Peder Bergebakken Sundt
75a918c9f0 python313Packages.hdf5plugin: 5.0.0 -> 5.1.0
release: https://github.com/silx-kit/hdf5plugin/releases/tag/v5.1.0

Of note is that they added a environment variable to build filters with system libraries
2025-05-13 10:51:18 +02:00
R. Ryantm
ab2103a345 quarkus: 3.21.4 -> 3.22.2 2025-05-12 05:04:55 +00:00
R. Ryantm
ad4019c3ae microsoft-edge: 135.0.3179.85 -> 136.0.3240.64 2025-05-11 18:09:53 +00:00
Nikolay Korotkiy
4a9ddcc498 telescope: 0.10.1 → 0.11 2025-05-11 21:24:55 +04:00
Nikolay Korotkiy
776f0ecd96 trayscale: 0.14.3 → 0.16.0 2025-05-11 15:48:01 +04:00
nomaterials
a53f3b5f7e maintainers: add nomaterials 2025-05-10 13:00:54 +02:00
goodylove
5c45af7c47 maintainers: add goodylove 2025-05-09 15:59:03 +01:00
Marcel
e03123d508 nixos/minecraft-server: update outdated links
The minecraft wiki moved to <https://minecraft.wiki>

https://www.reddit.com/r/Minecraft/comments/16r3y8x/the_minecraft_wiki_has_moved_from_fandom_to/
2025-05-09 14:09:50 +02:00
Sefa Eyeoglu
d95f6a109b immich: use our own esbuild
This fixes aarch64 builds, as the upstream lockfile does not include
binaries for aarch64.

Closes https://github.com/NixOS/nixpkgs/issues/404089

Signed-off-by: Sefa Eyeoglu <contact@scrumplex.net>
2025-05-07 19:14:08 +02:00
Emilia
3f1cf450d1 maintainers: add emilia 2025-05-04 04:45:45 +02:00
R. Ryantm
c6cc6b0f27 circleci-cli: 0.1.31543 -> 0.1.31632 2025-04-24 14:28:08 +00:00
bornav
43ead788f9 Made service restart after 5s 2025-04-19 12:09:28 +02:00
Sandro Jäckel
484b00be20 nixos/etc: remove rogue continue 2025-04-19 03:01:40 +02:00
Luna Perego
b40764fbd2 gnomeExtensions.guillotine: 25 -> 26 2025-03-24 19:09:34 +01:00
111 changed files with 6897 additions and 935 deletions

View File

@@ -25,8 +25,9 @@ For new packages please briefly describe the package or provide a link to its ho
- made sure NixOS tests are [linked](https://github.com/NixOS/nixpkgs/blob/master/pkgs/README.md#linking-nixos-module-tests-to-a-package) to the relevant packages
- [ ] Tested compilation of all packages that depend on this change using `nix-shell -p nixpkgs-review --run "nixpkgs-review rev HEAD"`. Note: all changes have to be committed, also see [nixpkgs-review usage](https://github.com/Mic92/nixpkgs-review#usage)
- [ ] Tested basic functionality of all binary files (usually in `./result/bin/`)
- [25.05 Release Notes](https://github.com/NixOS/nixpkgs/blob/master/nixos/doc/manual/release-notes/rl-2505.section.md) (or backporting [24.11](https://github.com/NixOS/nixpkgs/blob/master/nixos/doc/manual/release-notes/rl-2411.section.md) and [25.05](https://github.com/NixOS/nixpkgs/blob/master/nixos/doc/manual/release-notes/rl-2505.section.md) Release notes)
- [Nixpkgs 25.11 Release Notes](https://github.com/NixOS/nixpkgs/blob/master/doc/release-notes/rl-2511.section.md) (or backporting [24.11](https://github.com/NixOS/nixpkgs/blob/master/nixos/doc/release-notes/rl-2411.section.md) and [25.05](https://github.com/NixOS/nixpkgs/blob/master/doc/manual/release-notes/rl-2505.section.md) Nixpkgs Release notes)
- [ ] (Package updates) Added a release notes entry if the change is major or breaking
- [NixOS 25.11 Release Notes](https://github.com/NixOS/nixpkgs/blob/master/nixos/doc/manual/release-notes/rl-2511.section.md) (or backporting [24.11](https://github.com/NixOS/nixpkgs/blob/master/nixos/doc/manual/release-notes/rl-2411.section.md) and [25.05](https://github.com/NixOS/nixpkgs/blob/master/nixos/doc/manual/release-notes/rl-2505.section.md) NixOS Release notes)
- [ ] (Module updates) Added a release notes entry if the change is significant
- [ ] (Module addition) Added a release notes entry if adding a new NixOS module
- [ ] Fits [CONTRIBUTING.md](https://github.com/NixOS/nixpkgs/blob/master/CONTRIBUTING.md).

View File

@@ -31,7 +31,7 @@ jobs:
into: staging-next-24.11
- from: staging-next-24.11
into: staging-24.11
- from: master
- from: release-25.05
into: staging-next-25.05
- from: staging-next-25.05
into: staging-25.05

View File

@@ -345,7 +345,7 @@ See [Nix Channel Status](https://status.nixos.org/) for the current channels and
Here's a brief overview of the main Git branches and what channels they're used for:
- `master`: The main branch, used for the unstable channels such as `nixpkgs-unstable`, `nixos-unstable` and `nixos-unstable-small`.
- `release-YY.MM` (e.g. `release-25.05`): The NixOS release branches, used for the stable channels such as `nixos-25.05`, `nixos-25.05-small` and `nixpkgs-25.05-darwin`.
- `release-YY.MM` (e.g. `release-25.11`): The NixOS release branches, used for the stable channels such as `nixos-25.11`, `nixos-25.11-small` and `nixpkgs-25.11-darwin`.
When a channel is updated, a corresponding Git branch is also updated to point to the corresponding commit.
So e.g. the [`nixpkgs-unstable` branch](https://github.com/nixos/nixpkgs/tree/nixpkgs-unstable) corresponds to the Git commit from the [`nixpkgs-unstable` channel](https://channels.nixos.org/nixpkgs-unstable).

View File

@@ -35,18 +35,21 @@ rustPlatform.buildRustPackage (finalAttrs: {
hash = "...";
};
nativeBuildInputs = [
# Pull in our main hook
cargo-tauri.hook
nativeBuildInputs =
[
# Pull in our main hook
cargo-tauri.hook
# Setup npm
nodejs
npmHooks.npmConfigHook
# Setup npm
nodejs
npmHooks.npmConfigHook
# Make sure we can find our libraries
pkg-config
wrapGAppsHook4
];
# Make sure we can find our libraries
pkg-config
]
++ lib.optionals stdenv.hostPlatform.isLinux [
wrapGAppsHook4
];
buildInputs =
[ openssl ]

View File

@@ -3,5 +3,6 @@
This section lists the release notes for each stable version of Nixpkgs and current unstable revision.
```{=include=} sections
rl-2511.section.md
rl-2505.section.md
```

View File

@@ -1,4 +1,4 @@
# Nixpkgs 25.11 (2025.11/??) {#sec-nixpkgs-release-25.11}
# Nixpkgs 25.11 ("Xantusia", 2025.11/??) {#sec-nixpkgs-release-25.11}
## Highlights {#sec-nixpkgs-release-25.11-highlights}
<!-- To avoid merge conflicts, consider adding your item at an arbitrary place in the list instead. -->

View File

@@ -1 +1 @@
25.05
25.11

View File

@@ -439,7 +439,7 @@ in
On each release the first letter is bumped and a new animal is chosen
starting with that new letter.
*/
codeName = "Warbler";
codeName = "Xantusia";
/**
Returns the current nixpkgs version suffix as string.

View File

@@ -4811,6 +4811,12 @@
name = "Coca";
keys = [ { fingerprint = "99CB 86FF 62BB 7DA4 8903 B16D 0328 2DF8 8179 AB19"; } ];
};
cococolanosugar = {
name = "George Xu";
github = "cococolanosugar";
githubId = 1736138;
email = "cococolanosugar@gmail.com";
};
coconnor = {
email = "coreyoconnor@gmail.com";
github = "coreyoconnor";
@@ -7292,6 +7298,13 @@
githubId = 428026;
name = "embr";
};
emilia = {
email = "nix@emilia.codes";
github = "emiliaaah";
githubId = 55017867;
name = "Emilia";
keys = [ { fingerprint = "F772 3569 4B43 B599 73C2 A931 1EFB E941 B89B B810"; } ];
};
emilioziniades = {
email = "emilioziniades@protonmail.com";
github = "emilioziniades";
@@ -9182,6 +9195,12 @@
githubId = 1621335;
name = "Andrew Trachenko";
};
goodylove = {
github = "goodylove";
email = "goodyc474@gmail.com";
githubId = 104577296;
name = "Nwachukwu Goodness";
};
gordon-bp = {
email = "gordy@hanakano.com";
github = "Gordon-BP";
@@ -17753,6 +17772,12 @@
githubId = 41154684;
name = "nokazn";
};
nomaterials = {
email = "nomaterials@gmail.com";
github = "no-materials";
githubId = 16938952;
name = "nomaterials";
};
nomeata = {
email = "mail@joachim-breitner.de";
github = "nomeata";
@@ -27290,12 +27315,6 @@
githubId = 5986078;
name = "Zunway Liang";
};
zanculmarktum = {
name = "Azure Zanculmarktum";
email = "zanculmarktum@gmail.com";
github = "zanculmarktum";
githubId = 16958511;
};
zane = {
name = "Zane van Iperen";
email = "zane@zanevaniperen.com";

View File

@@ -869,6 +869,7 @@ with lib.maintainers;
qyriad
_9999years
lf-
alois31
];
scope = "Maintain the Lix package manager inside of Nixpkgs.";
shortName = "Lix ecosystem";
@@ -1119,9 +1120,17 @@ with lib.maintainers;
};
sdl = {
members = [ ];
scope = "Maintain SDL libraries.";
members = [
evythedemon
grimmauld
jansol
marcin-serwin
pbsds
];
githubTeams = [ "SDL" ];
scope = "Maintain core SDL libraries.";
shortName = "SDL";
enableFeatureFreezePing = true;
};
sphinx = {

View File

@@ -1994,6 +1994,9 @@
"sec-release-25.05-notable-changes": [
"release-notes.html#sec-release-25.05-notable-changes"
],
"sec-release-25.05-wiki": [
"release-notes.html#sec-release-25.05-wiki"
],
"sec-nixpkgs-release-25.05": [
"release-notes.html#sec-nixpkgs-release-25.05"
],

View File

@@ -3,6 +3,7 @@
This section lists the release notes for each stable version of NixOS and current unstable revision.
```{=include=} sections
rl-2511.section.md
rl-2505.section.md
rl-2411.section.md
rl-2405.section.md

View File

@@ -646,6 +646,10 @@
<!-- To avoid merge conflicts, consider adding your item at an arbitrary place in the list instead. -->
## NixOS Wiki {#sec-release-25.05-wiki}
The official NixOS Wiki at [wiki.nixos.org](https://wiki.nixos.org) has new and improved articles, new contributors and some improvements in its dark theme and mobile readability.
```{=include=} sections
../release-notes-nixpkgs/rl-2505.section.md
```

View File

@@ -1,4 +1,4 @@
# Release 25.11 (2025.11/??) {#sec-release-25.11}
# Release 25.11 ("Xantusia", 2025.11/??) {#sec-release-25.11}
## Highlights {#sec-release-25.11-highlights}

View File

@@ -45,7 +45,7 @@ let
# To be able to open the firewall, we need to read out port values in the
# server properties, but fall back to the defaults when those don't exist.
# These defaults are from https://minecraft.gamepedia.com/Server.properties#Java_Edition_3
# These defaults are from https://minecraft.wiki/w/Server.properties#Java_Edition
defaultServerPort = 25565;
serverPort = cfg.serverProperties.server-port or defaultServerPort;
@@ -93,10 +93,8 @@ in
type = lib.types.bool;
default = false;
description = ''
Whether you agree to
[
Mojangs EULA](https://account.mojang.com/documents/minecraft_eula). This option must be set to
`true` to run Minecraft server.
Whether you agree to [Mojangs EULA](https://www.minecraft.net/eula).
This option must be set to `true` to run Minecraft server.
'';
};
@@ -167,10 +165,10 @@ in
}
'';
description = ''
Minecraft server properties for the server.properties file. Only has
Minecraft server properties forthe server.properties file. Only has
an effect when {option}`services.minecraft-server.declarative`
is set to `true`. See
<https://minecraft.gamepedia.com/Server.properties#Java_Edition_3>
<https://minecraft.wiki/w/Server.properties#Java_Edition>
for documentation on these values.
'';
};
@@ -182,7 +180,7 @@ in
jvmOpts = lib.mkOption {
type = lib.types.separatedString " ";
default = "-Xmx2048M -Xms2048M";
# Example options from https://minecraft.gamepedia.com/Tutorials/Server_startup_script
# Example options from https://minecraft.wiki/w/Tutorial:Server_startup_script
example =
"-Xms4092M -Xmx4092M -XX:+UseG1GC -XX:+CMSIncrementalPacing "
+ "-XX:+CMSClassUnloadingEnabled -XX:ParallelGCThreads=2 "

View File

@@ -633,6 +633,7 @@ in
in
{
Restart = "always";
RestartSec = "5s";
Type = "simple";
User = cfg.user;
Group = cfg.group;

View File

@@ -41,8 +41,6 @@ let
if [ "$(readlink "$out/etc/$target")" != "$src" ]; then
echo "mismatched duplicate entry $(readlink "$out/etc/$target") <-> $src"
ret=1
continue
fi
fi

View File

@@ -632,6 +632,7 @@ let
grubUseEfi ? false,
enableOCR ? false,
meta ? { },
passthru ? { },
testSpecialisationConfig ? false,
testFlakeSwitch ? false,
testByAttrSwitch ? false,
@@ -644,7 +645,7 @@ let
isEfi = bootLoader == "systemd-boot" || (bootLoader == "grub" && grubUseEfi);
in
makeTest {
inherit enableOCR;
inherit enableOCR passthru;
name = "installer-" + name;
meta = {
# put global maintainers here, individuals go into makeInstallerTest fkt call
@@ -1109,10 +1110,12 @@ in
# The (almost) simplest partitioning scheme: a swap partition and
# one big filesystem partition.
simple = makeInstallerTest "simple" simple-test-config;
lix-simple = makeInstallerTest "simple" simple-test-config // {
selectNixPackage = pkgs: pkgs.lix;
};
simple = makeInstallerTest "simple" (
simple-test-config
// {
passthru.override = args: makeInstallerTest "simple" simple-test-config // args;
}
);
switchToFlake = makeInstallerTest "switch-to-flake" simple-test-config-flake;

View File

@@ -3,20 +3,16 @@
let
inherit (pkgs) lib;
tests = {
default = testsForPackage { nixPackage = pkgs.nix; };
lix = testsForPackage { nixPackage = pkgs.lix; };
};
tests.default = testsForPackage { nixPackage = pkgs.nix; };
testsForPackage =
args:
lib.recurseIntoAttrs {
# If the attribute is not named 'test'
# You will break all the universe on the release-*.nix side of things.
# `discoverTests` relies on `test` existence to perform a `callTest`.
test = testMiscFeatures args;
passthru.override = args': testsForPackage (args // args');
testsForPackage = args: {
# If the attribute is not named 'test'
# You will break all the universe on the release-*.nix side of things.
# `discoverTests` relies on `test` existence to perform a `callTest`.
test = testMiscFeatures args // {
passthru.override = args': (testsForPackage (args // args')).test;
};
};
testMiscFeatures =
{ nixPackage, ... }:

View File

@@ -137,6 +137,19 @@ final: prev: {
meta.hydraPlatforms = [ ];
};
GPTModels-nvim = buildVimPlugin {
pname = "GPTModels.nvim";
version = "2025-05-15";
src = fetchFromGitHub {
owner = "Aaronik";
repo = "GPTModels.nvim";
rev = "04d91c778d74f762143203ab81e155eec642b5f6";
sha256 = "06spvkfc1bhckq8w56w6ha4gzk60wfhjlyivrx51awz20sd6hyw0";
};
meta.homepage = "https://github.com/Aaronik/GPTModels.nvim/";
meta.hydraPlatforms = [ ];
};
Improved-AnsiEsc = buildVimPlugin {
pname = "Improved-AnsiEsc";
version = "2015-08-26";
@@ -8917,12 +8930,12 @@ final: prev: {
neogit = buildVimPlugin {
pname = "neogit";
version = "2025-04-16";
version = "2025-05-15";
src = fetchFromGitHub {
owner = "NeogitOrg";
repo = "neogit";
rev = "9bb1e73c534f767607e0a888f3de4c942825c501";
sha256 = "06qcyz3snk8bphbd2n9q4dzizkksn65is0nksd76q0zzkvb9qxhp";
rev = "6de4b9f9a92917f9aea3a0dbdc3dbbedc11d26be";
sha256 = "0z9qri9sp1aicma1yiy2vkdjixjj7pbprd86nmslrhrnchvnqrbh";
};
meta.homepage = "https://github.com/NeogitOrg/neogit/";
meta.hydraPlatforms = [ ];

View File

@@ -1314,6 +1314,13 @@ in
];
};
GPTModels-nvim = super.GPTModels-nvim.overrideAttrs {
dependencies = with self; [
nui-nvim
telescope-nvim
];
};
guard-collection = super.guard-collection.overrideAttrs {
dependencies = [ self.guard-nvim ];
};

View File

@@ -9,6 +9,7 @@ https://github.com/whonore/Coqtail/,,
https://github.com/vim-scripts/DoxygenToolkit.vim/,,
https://github.com/numToStr/FTerm.nvim/,,
https://github.com/antoinemadec/FixCursorHold.nvim/,,
https://github.com/Aaronik/GPTModels.nvim/,HEAD,
https://github.com/vim-scripts/Improved-AnsiEsc/,,
https://github.com/ionide/Ionide-vim/,HEAD,
https://github.com/martinda/Jenkinsfile-vim-syntax/,,

View File

@@ -27,8 +27,8 @@ let
mktplcRef = {
name = "language-x86-64-assembly";
publisher = "13xforever";
version = "3.1.4";
hash = "sha256-FJRDm1H3GLBfSKBSFgVspCjByy9m+j9OStlU+/pMfs8=";
version = "3.1.5";
hash = "sha256-WIhmAZLR2WOSqQF3ozJ/Vr3Rp6HdSK7L23T3h4AVaGM=";
};
meta = {
description = "Cutting edge x86 and x86_64 assembly syntax highlighting";
@@ -89,8 +89,8 @@ let
mktplcRef = {
publisher = "42Crunch";
name = "vscode-openapi";
version = "4.33.1";
hash = "sha256-iq0UpVaZMOzh4NIRPLk49ciFuO4A6PDSEMe1KKhfSxA=";
version = "4.33.2";
hash = "sha256-agCxi2UhJitdQmHIf6rK7WexkfljUQdqK5rLqzV4J6o=";
};
meta = {
changelog = "https://marketplace.visualstudio.com/items/42Crunch.vscode-openapi/changelog";
@@ -4027,8 +4027,8 @@ let
mktplcRef = {
publisher = "redhat";
name = "java";
version = "1.41.2025031208";
hash = "sha256-0VWLkztB7anIs19QN1yPQvVjNim+DICv43IOMwEaM+E=";
version = "1.42.0";
hash = "sha256-m6RJm8eleMjDNy5ixfXWtOcPmsjNynCUNuF9lsCB8ho=";
};
buildInputs = [ jdk ];
meta = {

View File

@@ -8,8 +8,8 @@ vscode-utils.buildVscodeMarketplaceExtension {
mktplcRef = {
publisher = "RooVeterinaryInc";
name = "roo-cline";
version = "3.16.5";
hash = "sha256-UbOLY1qHYOoMQq3Agm2qI2+I6YLwv2kec6nqPyGZha4=";
version = "3.17.1";
hash = "sha256-gfzn0KulOHUKcG3LNF7+g7VwkDHR4BYsmq730Uuv2ZU=";
};
passthru.updateScript = vscode-extension-update-script { };

View File

@@ -40,11 +40,11 @@
python3.pkgs.buildPythonApplication rec {
pname = "gajim";
version = "2.1.1";
version = "2.2.0";
src = fetchurl {
url = "https://gajim.org/downloads/${lib.versions.majorMinor version}/gajim-${version}.tar.gz";
hash = "sha256-1pPrc7lzxaLK1QbxslGYGS8xOxuT231RvZrdvWeGFOk=";
hash = "sha256-TOZuMiE5RjaJYvNWxl2FyCp6uIO+LLWiRb7N9jc1yRk=";
};
format = "pyproject";

View File

@@ -8,22 +8,22 @@
rustPlatform.buildRustPackage (finalAttrs: {
pname = "amazon-q-cli";
version = "1.9.1";
version = "1.10.0";
src = fetchFromGitHub {
owner = "aws";
repo = "amazon-q-developer-cli";
tag = "v${finalAttrs.version}";
hash = "sha256-BiVCiMBL5LLm8RYw58u6P7yqQq9XnN8b6fTbxNE2QsA=";
hash = "sha256-X1L3Nrzchp8yuGGBwwLQ4ZE41GKH3pFR2CX77TYYhNo=";
};
useFetchCargoVendor = true;
cargoHash = "sha256-7zUgWLGTZx3Ex7RYxb3eZimWdy6AxkNwpCDUwiAr2JE=";
cargoHash = "sha256-qtQ+e0NRzzGn0s2zpnMNUv7JdQDuImMfyC0C/QZrpjU=";
cargoBuildFlags = [
"-p"
"q_cli"
"chat_cli"
];
nativeBuildInputs = [
@@ -31,12 +31,12 @@ rustPlatform.buildRustPackage (finalAttrs: {
];
postInstall = ''
install -m 0755 $out/bin/q_cli $out/bin/amazon-q
install -m 0755 $out/bin/chat_cli $out/bin/amazon-q
'';
cargoTestFlags = [
"-p"
"q_cli"
"chat_cli"
];
# skip integration tests that have external dependencies
@@ -60,6 +60,7 @@ rustPlatform.buildRustPackage (finalAttrs: {
"--skip=init_lint_zsh_post_zshrc"
"--skip=init_lint_zsh_pre_zprofile"
"--skip=init_lint_zsh_pre_zshrc"
"--skip=telemetry::cognito::test::pools"
];
doInstallCheck = true;

View File

@@ -6,11 +6,11 @@
stdenvNoCC.mkDerivation rec {
pname = "amiri";
version = "1.001";
version = "1.002";
src = fetchzip {
url = "https://github.com/alif-type/amiri/releases/download/${version}/Amiri-${version}.zip";
hash = "sha256-YwiDY5/Ty5Pwj3d8+UafUNLVZ3omRtFRWQCLn2RkheM=";
hash = "sha256-Ln2AFiQ5hX4w1yu5NCF28S0hmfWUhEINi1YJVV/Gngo=";
};
installPhase = ''

View File

@@ -11,11 +11,11 @@
stdenv.mkDerivation rec {
pname = "bird";
version = "3.0.2";
version = "3.1.1";
src = fetchurl {
url = "https://bird.network.cz/download/bird-${version}.tar.gz";
hash = "sha256-eKqL5820LfFLnilpu2Q7IoxoBMZXj5CTsXPOiiQ3zDA=";
url = "https://bird.nic.cz/download/bird-${version}.tar.gz";
hash = "sha256-KXJRl0/4g+TvA/zNbJEtEW7Un/Lxxjtm0dul8HCUREo=";
};
nativeBuildInputs = [
@@ -43,7 +43,7 @@ stdenv.mkDerivation rec {
meta = with lib; {
changelog = "https://gitlab.nic.cz/labs/bird/-/blob/v${version}/NEWS";
description = "BIRD Internet Routing Daemon";
homepage = "https://bird.network.cz";
homepage = "https://bird.nic.cz/";
license = licenses.gpl2Plus;
maintainers = with maintainers; [ herbetom ];
platforms = platforms.linux;

View File

@@ -18,13 +18,13 @@ let
in
stdenv.mkDerivation (finalAttrs: {
pname = "cherry-studio";
version = "1.3.2";
version = "1.3.4";
src = fetchFromGitHub {
owner = "CherryHQ";
repo = "cherry-studio";
tag = "v${finalAttrs.version}";
hash = "sha256-Tgd8MvxsiCDp2pdtz2MeCnTGY4Butw9V/UoTw0XEaIg=";
hash = "sha256-xCS8ZomIAVEnQ2SJRay/ii7xhPMO+ctc8C14Xrje8kI=";
};
postPatch = ''
@@ -41,7 +41,7 @@ stdenv.mkDerivation (finalAttrs: {
offlineCache = yarn-berry.fetchYarnBerryDeps {
inherit (finalAttrs) src missingHashes;
hash = "sha256-WUsG8mqozphU2YIT73KqMNP62TBiay3EiGrMBgd2QJw=";
hash = "sha256-cStjxlmOnoDfrt6z5jvpkHfIKyfZ9UFWbbZjnJLiTu4=";
};
nativeBuildInputs = [
@@ -89,7 +89,12 @@ stdenv.mkDerivation (finalAttrs: {
runHook preInstall
mkdir -p $out/opt/cherry-studio
cp -r dist/linux-unpacked/{resources,LICENSE*} $out/opt/cherry-studio
${
if stdenv.hostPlatform.isAarch64 then
"cp -r dist/linux-arm64-unpacked/{resources,LICENSE*} $out/opt/cherry-studio"
else
"cp -r dist/linux-unpacked/{resources,LICENSE*} $out/opt/cherry-studio"
}
install -Dm644 build/icon.png $out/share/pixmaps/cherry-studio.png
makeWrapper ${lib.getExe electron} $out/bin/cherry-studio \
--inherit-argv0 \

View File

@@ -7,13 +7,13 @@
buildGoModule rec {
pname = "circleci-cli";
version = "0.1.31543";
version = "0.1.31632";
src = fetchFromGitHub {
owner = "CircleCI-Public";
repo = pname;
rev = "v${version}";
sha256 = "sha256-0hikYA7oU3tTHZdEcxDzMXCg13+muk6V7MyqJwExm0A=";
sha256 = "sha256-3ufazu7DuUFp3aBxQ5MPlndECHSjvEIscYjlvE3j9G8=";
};
vendorHash = "sha256-H7q373HL6M6ETkXEY5tAwN32rx0eMkqRAAZ4kQf9rKk=";

View File

@@ -9,13 +9,13 @@
buildGoModule rec {
pname = "cloudflared";
version = "2025.4.0";
version = "2025.5.0";
src = fetchFromGitHub {
owner = "cloudflare";
repo = "cloudflared";
tag = version;
hash = "sha256-PKF7wP/ueLLhV8k3nMUm/c5fkg+7CwRf1oLnx0qbcA0=";
hash = "sha256-ZnkE9x4A9HoiSXzvYuzyW/dH08r0aJUk/q6gFVgtTjk=";
};
vendorHash = null;

View File

@@ -45,11 +45,11 @@ let
in
stdenvNoCC.mkDerivation (finalAttrs: {
pname = "copilot-language-server";
version = "1.312.0";
version = "1.322.0";
src = fetchzip {
url = "https://github.com/github/copilot-language-server-release/releases/download/${finalAttrs.version}/copilot-language-server-native-${finalAttrs.version}.zip";
hash = "sha256-glZR72+5lpghItwHuzDZKd/KONsCrjjCwcyNK0k9jr8=";
hash = "sha256-3AJTC4TI+sqTi1/B1XQZght7CClplWwIxjGmrt1E2ME=";
stripRoot = false;
};

View File

@@ -0,0 +1,37 @@
{
fetchFromGitHub,
lib,
stdenv,
}:
stdenv.mkDerivation {
pname = "finalmouse-udev-rules";
version = "0-unstable-2025-05-05";
src = fetchFromGitHub {
owner = "teamfinalmouse";
repo = "xpanel-linux-permissions";
rev = "60c4ed794bd946e467559cc572cf25bb99bf04b6";
hash = "sha256-E2xhm+8fFlxgIKjZlAvosLk/KgbmLk01BjK++y8laBc=";
};
dontUnpack = true;
installPhase = ''
runHook preInstall
install -Dpm644 $src/99-finalmouse.rules $out/lib/udev/rules.d/70-finalmouse.rules
runHook postInstall
'';
meta = {
homepage = "https://github.com/teamfinalmouse/xpanel-linux-permissions";
description = "udev rules that give NixOS permission to communicate with Finalmouse mice";
platforms = lib.platforms.linux;
license = lib.licenses.mit;
maintainers = with lib.maintainers; [
emilia
];
};
}

View File

@@ -7,14 +7,14 @@
python3Packages.buildPythonApplication rec {
pname = "flexget";
version = "3.15.38";
version = "3.15.42";
pyproject = true;
src = fetchFromGitHub {
owner = "Flexget";
repo = "Flexget";
tag = "v${version}";
hash = "sha256-quEqpF5oj1FLmQrIS4t3HwS23/m/QH/ZVijlQapt5Mc=";
hash = "sha256-ON0j5HYNbpHSwTMJgX/xPLjzLZXRDk1YogbhcwugxJE=";
};
pythonRelaxDeps = true;

File diff suppressed because it is too large Load Diff

View File

@@ -13,7 +13,7 @@
let
pname = "freeplane";
version = "1.12.8";
version = "1.12.10";
jdk = jdk17;
gradle = gradle_8;
@@ -22,7 +22,7 @@ let
owner = "freeplane";
repo = "freeplane";
rev = "release-${version}";
hash = "sha256-yzjzaobXuQH8CHz183ditL2LsCXU5xLh4+3El4Ffu20=";
hash = "sha256-08Rl3vhXtlylNDc1gh5aZJ9/RoxeyxpDbklmhMVJuq4=";
};
in
@@ -37,10 +37,11 @@ stdenvNoCC.mkDerivation (finalAttrs: {
];
patches = [
# Plugin update to support Gradle 8.13; remove when included in a release.
# freeplane is using the wrong repository for a plugin
# remove when https://github.com/freeplane/freeplane/pull/2453 is merged and released
(fetchpatch {
url = "https://github.com/freeplane/freeplane/commit/e58958783ef6f85ab00bf270c1f897093c4d7006.patch";
hash = "sha256-oQF/GbItl2ZEVlTKzojqk9xTWl8CVP7V3yig/py71hk=";
url = "https://github.com/amadejkastelic/freeplane/commit/973c49b7a73622e434bb86c8caea15383201b58a.patch";
hash = "sha256-iztFmISXZu8xKWqpwDYgBSl8ZSpZEtNriwM+EW1+s+Y=";
})
];

View File

@@ -49,14 +49,14 @@ let
in
stdenv.mkDerivation (finalAttrs: {
pname = "gamescope";
version = "3.16.7";
version = "3.16.9";
src = fetchFromGitHub {
owner = "ValveSoftware";
repo = "gamescope";
tag = finalAttrs.version;
fetchSubmodules = true;
hash = "sha256-q0yTOyu47tQXorFfnmRa4wrt0KRnyelLDmfcg4iwPfs=";
hash = "sha256-Dw9EErOINGoOlnNqroKR+fbRfMGL7Q13gP3E5iw4RhU=";
};
patches = [

View File

@@ -0,0 +1,42 @@
{
lib,
buildGoModule,
fetchFromGitHub,
}:
buildGoModule rec {
pname = "goctl";
version = "1.8.3";
src = fetchFromGitHub {
owner = "zeromicro";
repo = "go-zero";
tag = "v${version}";
hash = "sha256-v5WzqMotF9C7i9hTYSjaPmTwveBVDVn+SKQXYuS4Rdc=";
};
vendorHash = "sha256-tOIlfYiAI9m7oTZyPDCzTXg9XTwBb6EOVLzDfZnzL4E=";
modRoot = "tools/goctl";
subPackages = [ "." ];
doCheck = true;
ldflags = [
"-s"
"-w"
];
meta = {
description = "CLI handcuffle of go-zero, a cloud-native Go microservices framework";
longDescription = ''
goctl is a go-zero's built-in handcuffle that is a major
lever to increase development efficiency, generating code,
document, deploying k8s yaml, dockerfile, etc.
'';
homepage = "https://go-zero.dev";
license = lib.licenses.mit;
maintainers = with lib.maintainers; [ cococolanosugar ];
mainProgram = "goctl";
};
}

View File

@@ -171,11 +171,11 @@ let
linux = stdenv.mkDerivation (finalAttrs: {
inherit pname meta passthru;
version = "136.0.7103.59";
version = "136.0.7103.113";
src = fetchurl {
url = "https://dl.google.com/linux/chrome/deb/pool/main/g/google-chrome-stable/google-chrome-stable_${finalAttrs.version}-1_amd64.deb";
hash = "sha256-dki7Ci91OpqMtgS84ynsxBWoB862t+eWFlxHvZUAUjc=";
hash = "sha256-BnKKu7X34g+zg4rDqjVXT3Kx2E8Gn5ELqs3LQS3GCkg=";
};
# With strictDeps on, some shebangs were not being patched correctly
@@ -274,11 +274,11 @@ let
darwin = stdenvNoCC.mkDerivation (finalAttrs: {
inherit pname meta passthru;
version = "136.0.7103.49";
version = "136.0.7103.114";
src = fetchurl {
url = "http://dl.google.com/release2/chrome/dz4uae22obgiqcnhey5k6wspvu_136.0.7103.49/GoogleChrome-136.0.7103.49.dmg";
hash = "sha256-4eGfwVdts+tW4ouUKZg1EvnSYOu6CCBRMYie2hz2y00=";
url = "http://dl.google.com/release2/chrome/iwktnyywqpn7dye3zjzgosvevq_136.0.7103.114/GoogleChrome-136.0.7103.114.dmg";
hash = "sha256-myJawlgVBQlLtgBfSfCL5XfdnH8d7xd+j8JV2+2MZ/s=";
};
dontPatch = true;

View File

@@ -59,7 +59,7 @@ stdenv.mkDerivation (finalAttrs: {
homepage = "https://www.gnu.org/software/guile-sdl/";
description = "Guile bindings for SDL";
license = lib.licenses.gpl3Plus;
teams = [ lib.teams.sdl ];
maintainers = [ ];
inherit (guile.meta) platforms;
};
})

5272
pkgs/by-name/hy/hypercore/package-lock.json generated Normal file

File diff suppressed because it is too large Load Diff

View File

@@ -0,0 +1,38 @@
{
lib,
buildNpmPackage,
fetchFromGitHub,
nix-update-script,
}:
buildNpmPackage (finalAttrs: {
pname = "hypercore";
version = "11.7.0";
src = fetchFromGitHub {
owner = "holepunchto";
repo = "hypercore";
tag = "v${finalAttrs.version}";
hash = "sha256-ZAKWFSOIAQysK9+4YxbUiL0fVsqnGFqhwe9ps6ZXYv0=";
};
npmDepsHash = "sha256-ZJxVmQWKgHyKkuYfGIlANXFcROjI7fibg6mxIhDZowM=";
dontNpmBuild = true;
postPatch = ''
cp ${./package-lock.json} ./package-lock.json
'';
passthru.updateScript = nix-update-script { };
meta = {
description = "Secure, distributed append-only log";
homepage = "https://github.com/holepunchto/hypercore";
license = lib.licenses.mit;
teams = with lib.teams; [ ngi ];
maintainers = [ lib.maintainers.goodylove ];
platforms = lib.platforms.all;
};
})

View File

@@ -1,8 +1,8 @@
diff --git a/admin/Makefile.def b/admin/Makefile.def
index 43ef322..cad3de2 100644
index facc205..0daceaf 100644
--- a/admin/Makefile.def
+++ b/admin/Makefile.def
@@ -306,7 +306,7 @@ endif
@@ -310,7 +310,7 @@ endif
# Apple CLANG flags (identical to GCC)
ifeq ($(GAG_COMPILER_CKIND),clang)
@@ -11,7 +11,7 @@ index 43ef322..cad3de2 100644
ifeq ($(RELEASE_MODE),no)
OPTION_CFLAGS += -Wall
endif
@@ -356,7 +356,7 @@ endif
@@ -360,7 +360,7 @@ endif
# GFORTRAN flags
ifeq ($(GAG_COMPILER_FKIND),gfortran)
@@ -21,55 +21,17 @@ index 43ef322..cad3de2 100644
GLOBAL_FFLAGS += -fsanitize=address -fsanitize=null
# Can not be used with our memory(ip):
diff --git a/admin/define-system.sh b/admin/define-system.sh
index f68274d..dd1a9be 100644
index 36d4ab9..0233259 100644
--- a/admin/define-system.sh
+++ b/admin/define-system.sh
@@ -279,35 +279,22 @@ EOF
else
GAG_MACHINE=pc
fi
- if which gcc > /dev/null 2>&1; then
- DEFAULT_CCOMPILER=gcc
- fi
- if which g++ > /dev/null 2>&1; then
- DEFAULT_CXXCOMPILER=g++
- elif which clang++ > /dev/null 2>&1; then
- DEFAULT_CXXCOMPILER=clang++
- fi
- if which ifort > /dev/null 2>&1; then
- DEFAULT_FCOMPILER=ifort
- elif which gfortran > /dev/null 2>&1; then
- DEFAULT_FCOMPILER=gfortran
- fi
@@ -287,8 +287,8 @@ EOF
fi
elif [ `uname -p` = "arm" ]; then
defsys_message "WARNING: experimental ARM support"
GAG_MACHINE=arm64
- if which gcc > /dev/null 2>&1; then
- DEFAULT_CCOMPILER=gcc
- fi
- if which g++ > /dev/null 2>&1; then
- DEFAULT_CXXCOMPILER=g++
- elif which clang++ > /dev/null 2>&1; then
- DEFAULT_CXXCOMPILER=clang++
- fi
- if which ifort > /dev/null 2>&1; then
- DEFAULT_FCOMPILER=ifort
- elif which gfortran > /dev/null 2>&1; then
- DEFAULT_FCOMPILER=gfortran
- fi
+ fi
+ if which clang > /dev/null 2>&1; then
+ DEFAULT_CCOMPILER=clang
+ fi
+ if which clang++ > /dev/null 2>&1; then
+ DEFAULT_CXXCOMPILER=clang++
+ elif which g++ > /dev/null 2>&1; then
+ DEFAULT_CXXCOMPILER=g++
+ fi
+ if which ifort > /dev/null 2>&1; then
+ DEFAULT_FCOMPILER=ifort
+ elif which gfortran > /dev/null 2>&1; then
+ DEFAULT_FCOMPILER=gfortran
fi ;;
CYGWIN*)
if [ `uname -m | grep -c "x86_64"` -ne 0 ]; then
+ if which clang > /dev/null 2>&1; then
+ DEFAULT_CCOMPILER=clang
fi
if which clang++ > /dev/null 2>&1; then
DEFAULT_CXXCOMPILER=clang++

View File

@@ -26,15 +26,15 @@ let
in
stdenv.mkDerivation (finalAttrs: {
version = "4.4-01";
version = "4.5-01";
pname = "imager";
src = fetchurl {
# The recommended download link is on Nextcloud instance that
# requires to accept some general terms of use. Use a mirror at
# univ-grenoble-alpes.fr instead.
url = "https://cloud.univ-grenoble-alpes.fr/s/J6yEqA6yZ8tX9da/download?path=%2F&files=imager-dec24.tar.gz";
hash = "sha256-Pq92IsGY4heekm5zNGngnp6J6YiCHYAyuMT2RsD1/9o=";
url = "https://cloud.univ-grenoble-alpes.fr/s/J6yEqA6yZ8tX9da/download?path=%2F&files=imager-may25.tar.gz";
hash = "sha256-E3JjdVGEQ0I/ogYj0G1OZxfQ3hA+sRgA4LAfHK52Sec=";
};
nativeBuildInputs = [
@@ -55,9 +55,6 @@ stdenv.mkDerivation (finalAttrs: {
];
patches = [
# Update the Python link flag script from Gildas upstream
# version. This patch will be included in the the IMAGER release.
./python-ldflags.patch
# Use Clang as the default compiler on Darwin.
./clang.patch
# Replace hardcoded cpp with GAG_CPP (see below).

View File

@@ -1,104 +0,0 @@
diff --git a/app/main/src-tauri/tauri.conf.json b/app/main/src-tauri/tauri.conf.json
index 1114b19..c4cc8f4 100644
--- a/app/main/src-tauri/tauri.conf.json
+++ b/app/main/src-tauri/tauri.conf.json
@@ -23,7 +23,6 @@
"macOS": {
"frameworks": [],
"exceptionDomain": "",
- "signingIdentity": "-",
"providerShortName": null,
"entitlements": null
},

View File

@@ -16,19 +16,19 @@
rustPlatform.buildRustPackage (finalAttrs: {
pname = "ruff";
version = "0.11.9";
version = "0.11.10";
src = fetchFromGitHub {
owner = "astral-sh";
repo = "ruff";
tag = finalAttrs.version;
hash = "sha256-TJHBaru0L2pMdZ9omtJ+OqGP764fSwoP54xndWVV6ls=";
hash = "sha256-8psRFBhOzcFYYOU1aLf2tQwSZeWyn3TjUtfMR8HJ4FE=";
};
cargoBuildFlags = [ "--package=ruff" ];
useFetchCargoVendor = true;
cargoHash = "sha256-/xIQ8JJI2WfX3rxLZQCwsN2ylURqi+SjkBvnn0Hdij0=";
cargoHash = "sha256-KwTqm345bRwn5PXn/bTakiBNNjJCIstkXGpqtyCiK4k=";
nativeBuildInputs = [ installShellFiles ];

View File

@@ -73,5 +73,8 @@ rustPlatform.buildRustPackage rec {
platforms = [ "x86_64-linux" ];
maintainers = with maintainers; [ gaelreyrol ];
mainProgram = "scaphandre";
# Upstream needs to decide what to do about a broken dependency
# https://github.com/hubblo-org/scaphandre/issues/403
broken = true;
};
}

View File

@@ -1,13 +0,0 @@
--- a/attacher.c 2025-02-24 20:15:31.701820351 +0100
+++ b/attacher.c 2025-02-24 20:17:05.893826559 +0100
@@ -461,8 +461,8 @@
size_t len;
len = strlen(*av) + 1;
if (p + len >= m.m.command.cmd + ARRAY_SIZE(m.m.command.cmd) - 1)
- break;
+ Panic(0, "Total length of the command to send too large.\n");
- strncpy(p, *av, MAXPATHLEN);
+ memcpy(p, *av, len);
p += len;
}
*p = 0;

View File

@@ -10,11 +10,11 @@
stdenv.mkDerivation rec {
pname = "screen";
version = "5.0.0";
version = "5.0.1";
src = fetchurl {
url = "mirror://gnu/screen/screen-${version}.tar.gz";
hash = "sha256-8Eo50AoOXHyGpVM4gIkDCCrV301z3xov00JZdq7ZSXE=";
hash = "sha256-La429Ns3n/zRS2kVlrpuwYrDqeIrxHrCOXiatYQJhp0=";
};
configureFlags = [
@@ -25,13 +25,6 @@ stdenv.mkDerivation rec {
# We need _GNU_SOURCE so that mallocmock_reset() is defined: https://savannah.gnu.org/bugs/?66416
NIX_CFLAGS_COMPILE = "-D_GNU_SOURCE=1 -Wno-int-conversion -Wno-incompatible-pointer-types";
patches = [
# GNU Screen 5.0 uses strncpy incorrectly in SendCmdMessage
# This causes issues detected when using -D_FORTIFY_SOURCE=3
# e.g. https://savannah.gnu.org/bugs/index.php?66215
./buffer-overflow-SendCmdMessage.patch
];
nativeBuildInputs = [
autoreconfHook
];

View File

@@ -48,6 +48,7 @@ stdenv.mkDerivation rec {
mainProgram = "playsound";
platforms = platforms.unix;
license = licenses.zlib;
teams = [ lib.teams.sdl ];
homepage = "https://www.icculus.org/SDL_sound/";
};
}

View File

@@ -32,7 +32,7 @@ stdenv.mkDerivation {
description = "SDL 1.2 patched with libsixel support";
license = lib.licenses.lgpl21;
mainProgram = "sdl-config";
teams = [ lib.teams.sdl ];
maintainers = [ ];
platforms = lib.platforms.linux;
};
}

View File

@@ -30,7 +30,7 @@ stdenv.mkDerivation (finalAttrs: {
homepage = "https://sdl-stretch.sourceforge.net/";
description = "Stretch Functions For SDL";
license = lib.licenses.lgpl2;
teams = [ lib.teams.sdl ];
maintainers = [ ];
inherit (SDL.meta) platforms;
};
})

View File

@@ -103,9 +103,8 @@ stdenv.mkDerivation (finalAttrs: {
license = lib.licenses.zlib;
maintainers = with lib.maintainers; [
nadiaholmquist
grimmauld
marcin-serwin
];
teams = [ lib.teams.sdl ];
platforms = lib.platforms.all;
pkgConfigModules = [
"sdl2-compat"

View File

@@ -79,6 +79,7 @@ stdenv.mkDerivation (finalAttrs: {
homepage = "https://github.com/libsdl-org/SDL_image";
license = lib.licenses.zlib;
maintainers = [ lib.maintainers.evythedemon ];
teams = [ lib.teams.sdl ];
inherit (sdl3.meta) platforms;
};
})

View File

@@ -62,6 +62,7 @@ stdenv.mkDerivation (finalAttrs: {
charain
Emin017
];
teams = [ lib.teams.sdl ];
pkgConfigModules = [ "sdl3-ttf" ];
platforms = lib.platforms.all;
};

View File

@@ -226,6 +226,7 @@ stdenv.mkDerivation (finalAttrs: {
changelog = "https://github.com/libsdl-org/SDL/releases/tag/${finalAttrs.src.tag}";
license = lib.licenses.zlib;
maintainers = with lib.maintainers; [ getchoo ];
teams = [ lib.teams.sdl ];
platforms = lib.platforms.unix ++ lib.platforms.windows;
pkgConfigModules = [ "sdl3" ];
};

View File

@@ -8,14 +8,14 @@
python3Packages.buildPythonApplication rec {
pname = "snowflake-cli";
version = "3.7.1";
version = "3.7.2";
pyproject = true;
src = fetchFromGitHub {
owner = "snowflakedb";
repo = "snowflake-cli";
tag = "v${version}";
hash = "sha256-UhxjyXG2FQFhzhGjnmWSZr1LiW2/RHFvIAbvJP0I7oc=";
hash = "sha256-MCJl6Mkkkp9JkG+8ZNfWAYQFMJccdtKfPdcnfaY8Y3w=";
};
build-system = with python3Packages; [

View File

@@ -7,7 +7,7 @@
makeWrapper,
}:
let
version = "4.1.6";
version = "4.1.7";
inherit (stdenv.hostPlatform) system;
throwSystem = throw "tailwindcss has not been packaged for ${system} yet.";
@@ -22,10 +22,10 @@ let
hash =
{
aarch64-darwin = "sha256-vy5DrFSVROGpP4uvS32PtfSBWJbF/vpzE9L0/drOxLc=";
aarch64-linux = "sha256-BPkJ72DfdGdV9ajPO61hoNkhzCfmzZRt1A/sSKcbAok=";
x86_64-darwin = "sha256-PteOE9PWEtn7BNoVT/nw6tz4H5jBFyzOZmZGDxfaGVE=";
x86_64-linux = "sha256-BuaYnp+lBuNbzl3MMVo9xm2n+WJzQ3tb8UsPhgAhRlM=";
aarch64-darwin = "sha256-CjzOBmhnEW0c+V6utNKPROhAOx1ql2vG8S4G1hT6Wdo=";
aarch64-linux = "sha256-jEGaZiGW8FcmVRrQBr2DQfR7i+344MtlFofZrjwK4GY=";
x86_64-darwin = "sha256-TN7TKW561j9qvgadL/P/cQhhum1lCrsjNglhxgz9GSw=";
x86_64-linux = "sha256-BwYpKTWpdzxsh54X0jYlMi5EkOfo96CtDmiPquTe+YE=";
}
.${system} or throwSystem;
in

View File

@@ -10,17 +10,17 @@
rustPlatform.buildRustPackage rec {
pname = "tbtools";
version = "0.5.0";
version = "0.6.0";
src = fetchFromGitHub {
owner = "intel";
repo = "tbtools";
tag = "v${version}";
hash = "sha256-zq8q3JaoqWAQUat2gIW0Wimi/tZiC6XDphUVjH0viU4=";
hash = "sha256-xLMnB8KliwHVU5y4L7K0a43gfdhLKFxnAx4wxGL9xMc=";
};
useFetchCargoVendor = true;
cargoHash = "sha256-SAHIDjELm4qr4whoQVdt3EuNA72qFqXEg3H0hYr7yLc=";
cargoHash = "sha256-QuiDI2/XzhUKF7BGnoKeJ2143keJtmi+8WG1MpulLZo=";
nativeBuildInputs = [
pkg-config

View File

@@ -12,15 +12,15 @@
buildPackages,
}:
stdenv.mkDerivation rec {
stdenv.mkDerivation (finalAttrs: {
pname = "telescope";
version = "0.10.1";
version = "0.11";
src = fetchFromGitHub {
owner = "omar-polo";
repo = "telescope";
rev = version;
hash = "sha256-MVZ/pvDAETacQiEMEXM0gYM20LXqNiHtMfFGqS1vipY=";
tag = finalAttrs.version;
hash = "sha256-GKeUXa4RKYkoywrCrpenfLt10Rdj9L0xYI3tf2hFAbk=";
};
postPatch = ''
@@ -45,11 +45,11 @@ stdenv.mkDerivation rec {
"HOSTCC=${buildPackages.stdenv.cc}/bin/${buildPackages.stdenv.cc.targetPrefix}cc"
];
meta = with lib; {
meta = {
description = "Telescope is a w3m-like browser for Gemini";
homepage = "https://www.telescope-browser.org/";
license = licenses.isc;
maintainers = with maintainers; [ heph2 ];
platforms = platforms.unix;
homepage = "https://telescope-browser.org/";
license = lib.licenses.isc;
maintainers = with lib.maintainers; [ heph2 ];
platforms = lib.platforms.unix;
};
}
})

View File

@@ -12,16 +12,16 @@
buildGoModule rec {
pname = "trayscale";
version = "0.14.3";
version = "0.16.0";
src = fetchFromGitHub {
owner = "DeedleFake";
repo = "trayscale";
tag = "v${version}";
hash = "sha256-HIx3icecgu29jlrHpXfIXzJAxgKSgpeGexouiL2lYB8=";
hash = "sha256-Fvp75DaU/ZB4VZsUIgiSAg9eWU2JO6aGGwEYaC+VzIE=";
};
vendorHash = "sha256-hFUzFjQ8LWOKifDp3FiIUwdttX0FrPpRdtWj6fqE5uQ=";
vendorHash = "sha256-KC2eWO3pS8Xbq9FwWfT3bAodhxdTOzpvkBxzxPa9pUY=";
subPackages = [ "cmd/trayscale" ];

View File

@@ -7,16 +7,16 @@
}:
buildGoModule rec {
pname = "treefmt";
version = "2.2.1";
version = "2.3.0";
src = fetchFromGitHub {
owner = "numtide";
repo = "treefmt";
rev = "v${version}";
hash = "sha256-gNGDqCRPvXjbfDQkEP8UsEStL9fsvUVYWPv3d8o1Bq0=";
hash = "sha256-tDezwRWEfPz+u/i9Wz7MZULMmmIUwnl+5gcFU+dDj6Y=";
};
vendorHash = "sha256-47yOjk3eO5K0T01GUDvheJxoAJz0ZmiV2RdqTv01pYQ=";
vendorHash = "sha256-9yAvqz99YlBfFU/hGs1PB/sH0iOyWaVadqGhfXMkj5E=";
subPackages = [ "." ];

View File

@@ -0,0 +1,35 @@
{
fetchFromGitHub,
lib,
nix-update-script,
rustPlatform,
versionCheckHook,
}:
rustPlatform.buildRustPackage (finalAttrs: {
pname = "tuistash";
version = "0.7.1";
src = fetchFromGitHub {
owner = "edmocosta";
repo = "tuistash";
tag = "v${finalAttrs.version}";
hash = "sha256-LWmH/xHvdiY6lC7gsRh2gX31b9Fh4fWekrVdQ++8moQ=";
};
cargoHash = "sha256-mLtzdWHC7HN+hju71WQQZ4nJDMzybEfjzckbfeu32Qo=";
doInstallCheck = true;
nativeInstallCheckInputs = [ versionCheckHook ];
passthru.updateScript = nix-update-script { };
meta = {
description = "Terminal User Interface for Logstash";
homepage = "https://github.com/edmocosta/tuistash";
changelog = "https://github.com/edmocosta/tuistash/blob/v${finalAttrs.version}/CHANGELOG.md";
license = [ lib.licenses.asl20 ];
maintainers = [ lib.maintainers.kpbaks ];
mainProgram = "tuistash";
};
})

View File

@@ -20,17 +20,17 @@
rustPlatform.buildRustPackage (finalAttrs: {
pname = "uv";
version = "0.7.3";
version = "0.7.4";
src = fetchFromGitHub {
owner = "astral-sh";
repo = "uv";
tag = finalAttrs.version;
hash = "sha256-8yQnBAAzt6kjg1F1AVdLX4z4at8+vCA4lcSclkzXXGw=";
hash = "sha256-Lj+qznkYIO7tu12Db2k6hzfh02Ph+Nj6n6j7ncTbPXE=";
};
useFetchCargoVendor = true;
cargoHash = "sha256-kPJrVHFJcw3tHvLm0ddn4iBoBNK1MDDF0WNcqFfmA4o=";
cargoHash = "sha256-awKbKDyU8r7pdPlce0a0mLavrfnvMssyf/VDD6LRm7Q=";
buildInputs = [
rust-jemalloc-sys
@@ -83,7 +83,10 @@ rustPlatform.buildRustPackage (finalAttrs: {
asl20
mit
];
maintainers = with lib.maintainers; [ GaetanLepage ];
maintainers = with lib.maintainers; [
GaetanLepage
prince213
];
mainProgram = "uv";
};
})

View File

@@ -0,0 +1,28 @@
{
lib,
fetchFromGitea,
rustPlatform,
}:
rustPlatform.buildRustPackage (finalAttrs: {
pname = "uwu-colors";
version = "0.4.0";
src = fetchFromGitea {
domain = "codeberg.org";
owner = "q60";
repo = "uwu_colors";
tag = finalAttrs.version;
hash = "sha256-qzqfLTww0m1rv/7oJZrHMk63CtOk4RzY+Owx0oqlVzI=";
};
cargoHash = "sha256-R/IZUFr8Cir34c+C7Kq6FTFEERiInGMF8yFcC0uQ7Us=";
meta = {
description = "Simple LSP server made to display colors via textDocument/documentColor";
mainProgram = "uwu_colors";
homepage = "https://codeberg.org/q60/uwu_colors";
license = lib.licenses.unlicense;
maintainers = with lib.maintainers; [ vel ];
};
})

View File

@@ -0,0 +1,74 @@
{
lib,
stdenv,
fetchFromGitLab,
eigen,
hidapi,
libopus,
libpulseaudio,
portaudio,
qt6,
qt6Packages,
rtaudio,
}:
stdenv.mkDerivation (finalAttrs: {
pname = "wfview";
version = "2.10";
src = fetchFromGitLab {
owner = "eliggett";
repo = "wfview";
rev = "v${finalAttrs.version}";
hash = "sha256-bFTblsDtFAakbSJfSfKgvoxd1DTSv++rxU6R3/uWo+4=";
};
patches = [
# Remove syscalls during build to make it reproducible
# We also need to adjust some header paths for darwin
./remove-hard-encodings.patch
];
buildInputs =
[
eigen
hidapi
libopus
portaudio
rtaudio
qt6.qtbase
qt6.qtserialport
qt6.qtmultimedia
qt6.qtwebsockets
qt6Packages.qcustomplot
]
++ lib.optionals stdenv.hostPlatform.isLinux [
libpulseaudio
];
nativeBuildInputs = with qt6; [
wrapQtAppsHook
qmake
];
env.LANG = "C.UTF-8";
qmakeFlags = [ "wfview.pro" ];
postInstall = lib.optionalString stdenv.hostPlatform.isDarwin ''
mkdir -pv $out/Applications
mv -v "$out/bin/wfview.app" $out/Applications
# wrap executable to $out/bin
makeWrapper "$out/Applications/wfview.app/Contents/MacOS/wfview" "$out/bin/wfview"
'';
meta = {
description = "Open-source software for the control of modern Icom radios";
homepage = "https://wfview.org/";
license = lib.licenses.gpl3Only;
platforms = lib.platforms.unix;
mainProgram = "wfview";
maintainers = with lib.maintainers; [ Cryolitia ];
};
})

View File

@@ -0,0 +1,171 @@
diff --git a/audioconverter.h b/audioconverter.h
index d3cf510..308725d 100644
--- a/audioconverter.h
+++ b/audioconverter.h
@@ -20,13 +20,8 @@
#endif
/* Opus and Eigen */
-#ifndef Q_OS_LINUX
-#include "opus.h"
-#include <Eigen/Eigen>
-#else
#include "opus/opus.h"
#include <eigen3/Eigen/Eigen>
-#endif
#include "wfviewtypes.h"
diff --git a/audiodevices.h b/audiodevices.h
index 3521eb5..0569e49 100644
--- a/audiodevices.h
+++ b/audiodevices.h
@@ -13,11 +13,7 @@
#include <QFontMetrics>
#include <portaudio.h>
-#ifndef Q_OS_LINUX
-#include "RtAudio.h"
-#else
#include "rtaudio/RtAudio.h"
-#endif
#include "wfviewtypes.h"
diff --git a/rthandler.h b/rthandler.h
index b422cc2..02b1117 100644
--- a/rthandler.h
+++ b/rthandler.h
@@ -6,11 +6,7 @@
#include <QThread>
#include <QMutex>
-#ifndef Q_OS_LINUX
-#include "RtAudio.h"
-#else
#include "rtaudio/RtAudio.h"
-#endif
#include <QAudioFormat>
diff --git a/tciserver.h b/tciserver.h
index 9b38886..af56763 100644
--- a/tciserver.h
+++ b/tciserver.h
@@ -9,13 +9,8 @@
#include "cachingqueue.h"
/* Opus and Eigen */
-#ifndef Q_OS_LINUX
-#include "opus.h"
-#include <Eigen/Eigen>
-#else
#include "opus/opus.h"
#include <eigen3/Eigen/Eigen>
-#endif
#define TCI_AUDIO_LENGTH 4096
struct tciCommandStruct
diff --git a/wfmain.h b/wfmain.h
index 0404fda..e400a74 100644
--- a/wfmain.h
+++ b/wfmain.h
@@ -68,11 +68,7 @@
#include <memory>
#include <portaudio.h>
-#ifndef Q_OS_LINUX
-#include "RtAudio.h"
-#else
#include "rtaudio/RtAudio.h"
-#endif
#ifdef USB_CONTROLLER
#ifdef Q_OS_WIN
diff --git a/wfview.pro b/wfview.pro
index a0943bd..e8f97e1 100644
--- a/wfview.pro
+++ b/wfview.pro
@@ -62,10 +62,8 @@ win32:DEFINES += __WINDOWS_WASAPI__
#linux:DEFINES += __LINUX_OSS__
linux:DEFINES += __LINUX_PULSE__
macx:DEFINES += __MACOSX_CORE__
-!linux:SOURCES += ../rtaudio/RTAudio.cpp
-!linux:HEADERS += ../rtaudio/RTAUdio.h
-!linux:INCLUDEPATH += ../rtaudio
+macx:LIBS += -lrtaudio
linux:LIBS += -lpulse -lpulse-simple -lrtaudio -lpthread -ludev
win32:INCLUDEPATH += ../portaudio/include
@@ -107,8 +105,6 @@ win32:RC_ICONS = "resources/icons/Windows/wfview 512x512.ico"
macx{
ICON = resources/wfview.icns
- QMAKE_MACOSX_DEPLOYMENT_TARGET = 10.15
- QMAKE_APPLE_DEVICE_ARCHS = x86_64 arm64
MY_ENTITLEMENTS.name = CODE_SIGN_ENTITLEMENTS
MY_ENTITLEMENTS.value = resources/wfview.entitlements
QMAKE_MAC_XCODE_SETTINGS += MY_ENTITLEMENTS
@@ -120,8 +116,7 @@ macx{
QMAKE_TARGET_BUNDLE_PREFIX = org.wfview
-!win32:DEFINES += HOST=\\\"`hostname`\\\" UNAME=\\\"`whoami`\\\"
-!win32:DEFINES += GITSHORT="\\\"$(shell git -C \"$$PWD\" rev-parse --short HEAD)\\\""
+!win32:DEFINES += HOST=\\\"nixos\\\" UNAME=\\\"nix\\\" GITSHORT=\\\"0.0\\\"
win32:DEFINES += GITSHORT=\\\"$$system(git -C $$PWD rev-parse --short HEAD)\\\"
win32:DEFINES += HOST=\\\"$$system(hostname)\\\"
@@ -169,19 +164,8 @@ macx:LIBS += -framework CoreAudio -framework CoreFoundation -lpthread -lopus
CONFIG(debug, release|debug) {
- macos:LIBS += -L ../qcustomplot/qcustomplot-sharedlib/build -lqcustomplotd
-
- lessThan(QT_MAJOR_VERSION, 6) {
- linux:LIBS += $$system("/sbin/ldconfig -p | awk '/libQCustomPlotd.so/ {print \"-lQCustomPlotd\"}'")
- linux:LIBS += $$system("/sbin/ldconfig -p | awk '/libqcustomplotd2.so/ {print \"-lqcustomplotd2\"}'")
- linux:LIBS += $$system("/sbin/ldconfig -p | awk '/libqcustomplotd.so/ {print \"-lqcustomplotd\"}'")
-
- } else {
- linux:LIBS += $$system("/sbin/ldconfig -p | awk '/libQCustomPlotdQt6.so/ {print \"-lQCustomPlotdQt6\"}'")
- linux:LIBS += $$system("/sbin/ldconfig -p | awk '/libqcustomplotd2qt6.so/ {print \"-lqcustomplotd2qt6\"}'")
- linux:LIBS += $$system("/sbin/ldconfig -p | awk '/libqcustomplotdqt6.so/ {print \"-lqcustomplotdqt6\"}'")
- }
-
+ macos:LIBS += -lqcustomplotd
+ linux:LIBS += -lqcustomplotd
win32 {
contains(QMAKE_TARGET.arch, x86_64) {
LIBS += -L../opus/win32/VS2015/x64/DebugDLL/
@@ -211,17 +195,8 @@ CONFIG(debug, release|debug) {
}
} else {
- macos:LIBS += -L ../qcustomplot/qcustomplot-sharedlib/build -lqcustomplot
-
- lessThan(QT_MAJOR_VERSION, 6) {
- linux:LIBS += $$system("/sbin/ldconfig -p | awk '/libQCustomPlot.so/ {print \"-lQCustomPlot\"}'")
- linux:LIBS += $$system("/sbin/ldconfig -p | awk '/libqcustomplot2.so/ {print \"-lqcustomplot2\"}'")
- linux:LIBS += $$system("/sbin/ldconfig -p | awk '/libqcustomplot.so/ {print \"-lqcustomplot\"}'")
- } else {
- linux:LIBS += $$system("/sbin/ldconfig -p | awk '/libQCustomPlotQt6.so/ {print \"-lQCustomPlotQt6\"}'")
- linux:LIBS += $$system("/sbin/ldconfig -p | awk '/libqcustomplot2qt6.so/ {print \"-lqcustomplot2qt6\"}'")
- linux:LIBS += $$system("/sbin/ldconfig -p | awk '/libqcustomplotqt6.so/ {print \"-lqcustomplotqt6\"}'")
- }
+ macos:LIBS += -lqcustomplot
+ linux:LIBS += -lqcustomplot
win32 {
contains(QMAKE_TARGET.arch, x86_64) {
LIBS += -L../opus/win32/VS2015/x64/ReleaseDLL/
@@ -264,9 +239,6 @@ win32:LIBS += -lopus -lole32 -luser32
#macx:HEADERS += ../qcustomplot/qcustomplot.h
win32:INCLUDEPATH += ../qcustomplot
-!linux:INCLUDEPATH += ../opus/include
-!linux:INCLUDEPATH += ../eigen
-!linux:INCLUDEPATH += ../r8brain-free-src
INCLUDEPATH += resampler

View File

@@ -1,20 +1,20 @@
{
"aarch64-darwin": {
"version": "1.8.2",
"version": "1.9.0",
"vscodeVersion": "1.99.1",
"url": "https://windsurf-stable.codeiumdata.com/darwin-arm64/stable/eccc45da0d0c40e57275e0cce7db644c7b1278d8/Windsurf-darwin-arm64-1.8.2.zip",
"sha256": "d1d353f6f78b570500546a1a1ee140d195df7497ce3eb946fb159afd0cc34a67"
"url": "https://windsurf-stable.codeiumdata.com/darwin-arm64/stable/fbebfca390b10f7a152fd231f94606109d576e12/Windsurf-darwin-arm64-1.9.0.zip",
"sha256": "44706f90321bdc4c2a2320a03c79fdd01c911236daa4cc675c597851974a268c"
},
"x86_64-darwin": {
"version": "1.8.2",
"version": "1.9.0",
"vscodeVersion": "1.99.1",
"url": "https://windsurf-stable.codeiumdata.com/darwin-x64/stable/eccc45da0d0c40e57275e0cce7db644c7b1278d8/Windsurf-darwin-x64-1.8.2.zip",
"sha256": "920ea85cdb98755eeadabf69fa2ed56baf24df7273aa28a1ad7b33f2d4acb862"
"url": "https://windsurf-stable.codeiumdata.com/darwin-x64/stable/fbebfca390b10f7a152fd231f94606109d576e12/Windsurf-darwin-x64-1.9.0.zip",
"sha256": "ae398d597cd143144c2bdc8bf0a853a1c57b6de2c86c95087a4be5db78252e75"
},
"x86_64-linux": {
"version": "1.8.2",
"version": "1.9.0",
"vscodeVersion": "1.99.1",
"url": "https://windsurf-stable.codeiumdata.com/linux-x64/stable/eccc45da0d0c40e57275e0cce7db644c7b1278d8/Windsurf-linux-x64-1.8.2.tar.gz",
"sha256": "677793a06575428d95e1ad73a0063580f116c9467c100ca0b218b6a89262ba2b"
"url": "https://windsurf-stable.codeiumdata.com/linux-x64/stable/fbebfca390b10f7a152fd231f94606109d576e12/Windsurf-linux-x64-1.9.0.tar.gz",
"sha256": "941640e3514a5ee524943135b439219243adb288fec484712ebc2935173aa938"
}
}

View File

@@ -0,0 +1,23 @@
{
lib,
fetchFromGitHub,
mkYaziPlugin,
}:
mkYaziPlugin {
pname = "nord.yazi";
version = "0-unstable-2025-05-14";
src = fetchFromGitHub {
owner = "stepbrobd";
repo = "nord.yazi";
rev = "0f8eff4367021be1b741391d98853fbd1a34baf9";
hash = "sha256-bcYIbKFU1bvGRS6lgEBMe2jT13bECYgQATuh3QKmhQE=";
};
meta = {
description = "nordic yazi";
homepage = "https://github.com/stepbrobd/nord.yazi";
license = lib.licenses.mit;
maintainers = with lib.maintainers; [ stepbrobd ];
};
}

View File

@@ -5,13 +5,13 @@
}:
mkYaziPlugin {
pname = "restore.yazi";
version = "25.2.7-unstable-2025-04-04";
version = "25.2.7-unstable-2025-04-24";
src = fetchFromGitHub {
owner = "boydaihungst";
repo = "restore.yazi";
rev = "328dd888c1e2b9b0cb5dc806f099e3164e179620";
hash = "sha256-3Z8P25u9bffdjrPjxLRWUQn6MdBS+vyElUBkgV4EUwY=";
rev = "539aad5077dc8b342a580036e416f2b949b6590e";
hash = "sha256-ngwbweKF7pSEpzy1TNzbKz8cFIWaDison5vCiGxkHFk=";
};
meta = {

View File

@@ -9,13 +9,13 @@
# https://gitlab.com/ente76/guillotine/-/issues/17
stdenv.mkDerivation (finalAttrs: {
pname = "gnome-shell-extension-guillotine";
version = "25";
version = "26";
src = fetchFromGitLab {
owner = "ente76";
repo = "guillotine";
rev = "v${finalAttrs.version}";
hash = "sha256-HEk1owolLIea4kymoVVeviZ1Ms0kSuHWUda+u+uIh0A=";
hash = "sha256-6RuHargk7sq6oUKj+aGPFp3t0LJCpj6RwLhNzAM5wVA=";
};
nativeBuildInputs = [ glib ];

View File

@@ -3230,6 +3230,9 @@ self: super:
# 2025-04-19: Tests randomly fail 5 out of 10 times
fft = dontCheck super.fft;
# 2025-5-15: Too strict bounds on base <4.19, see: https://github.com/zachjs/sv2v/issues/317
sv2v = doJailbreak super.sv2v;
}
// import ./configuration-tensorflow.nix { inherit pkgs haskellLib; } self super

View File

@@ -5935,7 +5935,6 @@ broken-packages:
- supplemented # failure in job https://hydra.nixos.org/build/233237397 at 2023-09-02
- supply-chain-core # failure in job https://hydra.nixos.org/build/252715612 at 2024-03-16
- surjective # failure in job https://hydra.nixos.org/build/233242908 at 2023-09-02
- sv2v # failure in job https://hydra.nixos.org/build/295097359 at 2025-04-22
- sv-core # failure in job https://hydra.nixos.org/build/233217245 at 2023-09-02
- SVD2HS # failure in job https://hydra.nixos.org/build/233248575 at 2023-09-02
- svfactor # failure in job https://hydra.nixos.org/build/233256743 at 2023-09-02

View File

@@ -642669,9 +642669,7 @@ self: {
];
description = "SystemVerilog to Verilog conversion";
license = lib.licenses.bsd3;
hydraPlatforms = lib.platforms.none;
mainProgram = "sv2v";
broken = true;
}
) { };

View File

@@ -0,0 +1,68 @@
{
stdenv,
lib,
fetchFromGitLab,
fetchurl,
fixDarwinDylibNames,
qtbase,
qmake,
}:
stdenv.mkDerivation (finalAttrs: {
pname = "qcustomplot";
version = "2.1.1";
srcs = [
(fetchFromGitLab {
owner = "ecme2";
repo = "QCustomPlot";
tag = "v${finalAttrs.version}";
hash = "sha256-BW8H/vDbhK3b8t8oB92icEBemzcdRdrIz2aKqlUi6UU=";
})
(fetchurl {
url = "https://www.qcustomplot.com/release/${finalAttrs.version}/QCustomPlot-source.tar.gz";
hash = "sha256-Xi0i3sd5248B81fL2yXlT7z5ca2u516ujXrSRESHGC8=";
})
];
sourceRoot = ".";
buildInputs = [ qtbase ];
nativeBuildInputs =
[
qmake
]
++ lib.optionals stdenv.hostPlatform.isDarwin [
fixDarwinDylibNames
];
env.LANG = "C.UTF-8";
qmakeFlags = [ "sharedlib/sharedlib-compilation/sharedlib-compilation.pro" ];
dontWrapQtApps = true;
postUnpack = ''
cp -rv source/* .
cp -rv qcustomplot-source/* .
'';
installPhase = ''
runHook preInstall
install -vDm 644 "qcustomplot.h" -t "$out/include/"
install -vdm 755 "$out/lib/"
cp -av libqcustomplot*${stdenv.hostPlatform.extensions.sharedLibrary}* "$out/lib/"
runHook postInstall
'';
meta = {
homepage = "https://qtcustomplot.com/";
description = "Qt C++ widget for plotting and data visualization";
license = lib.licenses.gpl3Plus;
platforms = lib.platforms.unix;
maintainers = with lib.maintainers; [ Cryolitia ];
};
})

View File

@@ -359,7 +359,7 @@
buildPythonPackage rec {
pname = "boto3-stubs";
version = "1.38.13";
version = "1.38.16";
pyproject = true;
disabled = pythonOlder "3.7";
@@ -367,7 +367,7 @@ buildPythonPackage rec {
src = fetchPypi {
pname = "boto3_stubs";
inherit version;
hash = "sha256-j3OnRXRdXtOiBkJ/9GroLEjDf4bQ0mQ5WJi98OVWNSA=";
hash = "sha256-dZrhWJtN5u/rT0ehuEtObj536bNbT0bpqDTEmpEbfwQ=";
};
build-system = [ setuptools ];

View File

@@ -10,7 +10,7 @@
buildPythonPackage rec {
pname = "botocore-stubs";
version = "1.38.13";
version = "1.38.16";
pyproject = true;
disabled = pythonOlder "3.7";
@@ -18,7 +18,7 @@ buildPythonPackage rec {
src = fetchPypi {
pname = "botocore_stubs";
inherit version;
hash = "sha256-x2bLqukcE3oc5RYGAfTMIzEuvWCece16Pbz2qJazs1A=";
hash = "sha256-SOxutsOJI9Dg+UlOcshpRiq1/9NXi5HNLZH9lNNh4Dw=";
};
nativeBuildInputs = [ setuptools ];

View File

@@ -9,14 +9,14 @@
buildPythonPackage rec {
pname = "django-pglock";
version = "1.7.1";
version = "1.7.2";
pyproject = true;
src = fetchFromGitHub {
owner = "AmbitionEng";
repo = "django-pglock";
tag = version;
hash = "sha256-WbifapA2A0grxePozwDSPzREIzmgBV+V5wpA9jeYfJ8=";
hash = "sha256-FKAIftHNpfGzED0nkrLv3gVhfS7lyqfwZ1mEKsw/Vc8=";
};
build-system = [ poetry-core ];
@@ -31,7 +31,7 @@ buildPythonPackage rec {
meta = {
description = "Postgres advisory locks, table locks, and blocking lock management";
homepage = "https://github.com/AmbitionEng/django-pglock";
changelog = "https://github.com/AmbitionEng/django-pglock/blob/${version}/CHANGELOG.md";
changelog = "https://github.com/AmbitionEng/django-pglock/blob/${src.tag}/CHANGELOG.md";
license = lib.licenses.bsd3;
maintainers = with lib.maintainers; [ jopejoe1 ];
};

View File

@@ -5,30 +5,64 @@
setuptools,
py-cpuinfo,
h5py,
pkgconfig,
c-blosc2,
charls,
lz4,
zlib,
zstd,
}:
buildPythonPackage rec {
pname = "hdf5plugin";
version = "5.0.0";
version = "5.1.0";
pyproject = true;
src = fetchFromGitHub {
owner = "silx-kit";
repo = "hdf5plugin";
tag = "v${version}";
hash = "sha256-6lEU8ZGJKazDqloel5QcaXAbNGzV1fAbAjYC/hFUOdI=";
hash = "sha256-12OWsNZfKToNLyokNrwgPc7WRISJI4nRA0J/zwgCZwI=";
};
build-system = [
setuptools
py-cpuinfo
pkgconfig # only needed if HDF5PLUGIN_SYSTEM_LIBRARIES is used
];
dependencies = [ h5py ];
buildInputs = [
#c-blosc
c-blosc2
# bzip2_1_1
charls
lz4
# snappy
# zfp
zlib
zstd
];
# opt-in to use use system libs instead
env.HDF5PLUGIN_SYSTEM_LIBRARIES = lib.concatStringsSep "," [
#"blosc" # AssertionError: 4000 not less than 4000
"blosc2"
# "bz2" # only works with bzip2_1_1
"charls"
"lz4"
# "snappy" # snappy tests fail
# "sperr" # not packaged?
# "zfp" # pkgconfig: (lib)zfp not found
"zlib"
"zstd"
];
checkPhase = ''
python test/test.py
'';
pythonImportsCheck = [ "hdf5plugin" ];
preBuild = ''

View File

@@ -314,8 +314,8 @@ rec {
"sha256-Uek62hNK0eJRxRj9YiU4R44w33IUyrXZ9AyGbEcoiyc=";
mypy-boto3-cognito-idp =
buildMypyBoto3Package "cognito-idp" "1.38.0"
"sha256-ytRI2TYHsl90U3QtD1k8QVhsd5ILcJB3YjWLIVf7qH8=";
buildMypyBoto3Package "cognito-idp" "1.38.16"
"sha256-2IExKWR4xOJkI+HHJMemU88PoBsi5lzkTq03cUhFLv0=";
mypy-boto3-cognito-sync =
buildMypyBoto3Package "cognito-sync" "1.38.0"
@@ -358,8 +358,8 @@ rec {
"sha256-ABRIC59mat4ek0yrWxcHUr62whXmaZef47yDR7A2rl0=";
mypy-boto3-controltower =
buildMypyBoto3Package "controltower" "1.38.0"
"sha256-3yIoiaPmgYBOTCYk2RQyHWyhUlA0qZXUfLnhKESeUWU=";
buildMypyBoto3Package "controltower" "1.38.15"
"sha256-UdmjmkHw97cpq6vDS6d48a3DOLkZ/RJATTH8DxfhFpY=";
mypy-boto3-cur =
buildMypyBoto3Package "cur" "1.38.0"
@@ -446,8 +446,8 @@ rec {
"sha256-RQh46jrXqj4bXTRJ+tPR9sql7yUn7Ek9u4p0OU0A7b0=";
mypy-boto3-ec2 =
buildMypyBoto3Package "ec2" "1.38.12"
"sha256-NpOkYFCgUxUbk6SJXYWYN5/FMGs8aIzBVe/NhkLUoR0=";
buildMypyBoto3Package "ec2" "1.38.14"
"sha256-+EI+0aGCa21XL3qoAr821F/j8dJTCaLcVRKP743szUQ=";
mypy-boto3-ec2-instance-connect =
buildMypyBoto3Package "ec2-instance-connect" "1.38.0"
@@ -462,8 +462,8 @@ rec {
"sha256-aSZu8mxsTho4pvWWbNwlJf0IROjqjTlIUEE5DJkAje4=";
mypy-boto3-ecs =
buildMypyBoto3Package "ecs" "1.38.9"
"sha256-LxgLG+uNpChV9MZ/9xsF5RayVU5i2qjYp73jAQFBA6s=";
buildMypyBoto3Package "ecs" "1.38.15"
"sha256-2SM1EqTNnvyNEUbeTz9RmG3CsOfkQ3enuvQFOH2je8A=";
mypy-boto3-efs =
buildMypyBoto3Package "efs" "1.38.0"
@@ -534,8 +534,8 @@ rec {
"sha256-0Ln8pT0rhaR4xXe4gLPKQWuzuq2WJ1IyhvpUf3YKehM=";
mypy-boto3-firehose =
buildMypyBoto3Package "firehose" "1.38.0"
"sha256-mmOpANvBTUTilWXZ8h5tMTwffEawd6HwVBJppLe1Z74=";
buildMypyBoto3Package "firehose" "1.38.16"
"sha256-IL9bOLR3F7TMmJr/MUVBAQVOmZ8Bp/1cWOvMxEFzbUU=";
mypy-boto3-fis =
buildMypyBoto3Package "fis" "1.38.0"
@@ -606,8 +606,8 @@ rec {
"sha256-z839V1DLHxIkZrSjzWpLbAMGszL3UokIHAHwaVFhSDQ=";
mypy-boto3-iam =
buildMypyBoto3Package "iam" "1.38.0"
"sha256-Lh1EnEdDGQEWHNDQiDX5x08oF+TbzTd5IunMwYTqUs4=";
buildMypyBoto3Package "iam" "1.38.14"
"sha256-RpIgAHS/kX2nySN7LFC7uXGJMcn5m3PleezdEAtlgqM=";
mypy-boto3-identitystore =
buildMypyBoto3Package "identitystore" "1.38.0"
@@ -790,8 +790,8 @@ rec {
"sha256-hHMZReLH2J2vgdkECWREXAp/2ZOoJSynZU8epapC188=";
mypy-boto3-license-manager =
buildMypyBoto3Package "license-manager" "1.38.0"
"sha256-jDFm+V7sTX+oQeWt8aiW4yN2HeXz8fSu9ZjIn/vNoig=";
buildMypyBoto3Package "license-manager" "1.38.15"
"sha256-2zkjzEgJC9wzLiCTUU5XB3YXcX2OVeb8oOvpI/ITiaQ=";
mypy-boto3-license-manager-linux-subscriptions =
buildMypyBoto3Package "license-manager-linux-subscriptions" "1.38.0"
@@ -810,8 +810,8 @@ rec {
"sha256-uypKW3Cqj98SLeWmSwCXVKhKpXWXEvwdUexqqFgXeEc=";
mypy-boto3-logs =
buildMypyBoto3Package "logs" "1.38.13"
"sha256-VOkEcgDn4G1v1DB/Berg5yP+PYUf7YBfQ+T4yvATVBs=";
buildMypyBoto3Package "logs" "1.38.16"
"sha256-TE/PCNUYLj55t7JbGdv0UZ3OUvx0IgpYrL5b22KEnfM=";
mypy-boto3-lookoutequipment =
buildMypyBoto3Package "lookoutequipment" "1.38.0"
@@ -862,12 +862,12 @@ rec {
"sha256-F6Yv7tgHnzgsekH7HJ8s7/Kpq1JiZkHs+qZEez5snUI=";
mypy-boto3-mediaconvert =
buildMypyBoto3Package "mediaconvert" "1.38.9"
"sha256-n6yMEzEVwlorfkyPVf3wYsNjbTVvujEd6GR/SRPTCOk=";
buildMypyBoto3Package "mediaconvert" "1.38.16"
"sha256-13hTO6ZkJl+6IuEjJFl4Yy0McVURcRxfeefzgPnrULs=";
mypy-boto3-medialive =
buildMypyBoto3Package "medialive" "1.38.11"
"sha256-K0EgOaQKgTAoVlbPqc90j44OI+6YeHUEDe20hWjnyQQ=";
buildMypyBoto3Package "medialive" "1.38.14"
"sha256-AG2+2CVchluScgVnd8sPU3EpVyDcSmJ3HXxFVlU66Yw=";
mypy-boto3-mediapackage =
buildMypyBoto3Package "mediapackage" "1.38.0"
@@ -890,8 +890,8 @@ rec {
"sha256-OyelTdU5Rwh1zsYfbRZ6t+pJNt4y3S96U2KJEqrIdsk=";
mypy-boto3-mediatailor =
buildMypyBoto3Package "mediatailor" "1.38.0"
"sha256-LjWG40uhYRU6qpuTH4Vw8XUjzhv+CN5PhuV+CPu0sjc=";
buildMypyBoto3Package "mediatailor" "1.38.14"
"sha256-mhgPrqIp5UdrI+zhEXjmYQbBjyeX8vuiWhwg8tSfo+w=";
mypy-boto3-medical-imaging =
buildMypyBoto3Package "medical-imaging" "1.38.0"
@@ -1166,16 +1166,16 @@ rec {
"sha256-+P5YbkUSP/zTBaDDCEcSjzkx2IhknitMWlL0Ehg8hAo=";
mypy-boto3-s3control =
buildMypyBoto3Package "s3control" "1.38.0"
"sha256-KsxNSyn593BuTjScIt0Mo7oUGhUX150wi/oIDnAx+9I=";
buildMypyBoto3Package "s3control" "1.38.14"
"sha256-vCG6YvEf2ncO6cyqWW56LVXMh4dLzfz6uQAT50xzeuE=";
mypy-boto3-s3outposts =
buildMypyBoto3Package "s3outposts" "1.38.0"
"sha256-lBWZesgIKYnjSjUOPBhF4GNsNSk09YDSEyX0qweT3iM=";
mypy-boto3-sagemaker =
buildMypyBoto3Package "sagemaker" "1.38.11"
"sha256-jImugcJSB+LIaZsUBTyuI9yN3+D8Gw49l5j78VK4Now=";
buildMypyBoto3Package "sagemaker" "1.38.14"
"sha256-XKVR3rpjs3qNWapIjo28h2D5CywnrBYi8dEbkCtzRhg=";
mypy-boto3-sagemaker-a2i-runtime =
buildMypyBoto3Package "sagemaker-a2i-runtime" "1.38.0"

View File

@@ -16,7 +16,7 @@
buildPythonPackage rec {
pname = "nbxmpp";
version = "6.1.1";
version = "6.2.0";
format = "pyproject";
disabled = pythonOlder "3.10";
@@ -26,7 +26,7 @@ buildPythonPackage rec {
owner = "gajim";
repo = "python-nbxmpp";
rev = "refs/tags/${version}";
hash = "sha256-zuPaQCBXJl515MFSfJ2Y9cQtVccDGGSQzpZn3DTSa3Q=";
hash = "sha256-BaRLYuyn0acikX0Imsul2yY+w4jdtXTlE84hAovuZ/4=";
};
nativeBuildInputs = [

View File

@@ -31,10 +31,10 @@ let
defaultVersion = lib.switch rocq-core.rocq-version [
{
case = "9.0";
out = "2.5.1";
out = "2.5.2";
}
] null;
release."2.5.1".sha256 = "sha256-vw18iPPoI44tM8C05Wj4YvFAi1jjfyjZ90dbxX4NgQM=";
release."2.5.2".sha256 = "sha256-lLzjPrbVB3rrqox528YiheUb0u89R84Xmrgkn0oplOs=";
releaseRev = v: "v${v}";
mlPlugin = true;

Some files were not shown because too many files have changed in this diff Show More
diff --git a/admin/python-config-ldflags.py b/admin/python-config-ldflags.py
index 0854698..f397a7c 100644
--- a/admin/python-config-ldflags.py
+++ b/admin/python-config-ldflags.py
@@ -1,38 +1,70 @@
-#!/usr/bin/env python
+# This scripts retrieves the proper options to be used to link against
+# the libpython, in a machine-independant way. It invokes the official
+# script python-config (which thankfully deals with all the details).
-# DUPLICATE of "python-config --ldflags", fixed for the library location
+import sys
+newerpython = (sys.version_info[0] == 3 and sys.version_info[1] > 7)
-# This utility is known to work with:
-# python2.6 (system install) under SL6.4
-# python2.7 (custom install) under SL6.4
-# python3.4 (custom install) under SL6.4
-# python2.7 (system install) under Fedora20
-# python2.7 (Apple install) under MacOSX
-# python2.7 (MacPorts install) under MacOSX
-# python3.4 (MacPorts install) under MacOSX
+if newerpython:
+ # From now on avoid duplicating python-config, which evolves on its own.
+ # Invoke 'python-config --ldflags --embed'. The embed option (under
+ # Python 3) adds the libpython itself, whose name is highly
+ # unpredictible under the variety of machines and configurations we
+ # support
+ import subprocess
+ output = subprocess.check_output(['python-config', '--ldflags','--embed'])
+ output = output.decode('utf-8')
+ #print(output)
-import sys
-import sysconfig
+ args = output.split()
-pyver = sysconfig.get_config_var('VERSION')
-getvar = sysconfig.get_config_var
+ output = ''
+ for arg in args:
+ # Discard /usr/lib* path which causes troubles on the link command
+ # line, as it basically overrides all other custom paths coming after
+ # it. No need to put these paths on command line, they are found
+ # implicitly by the linker.
+ if arg not in ['-L/usr/lib','-L/usr/lib32','-L/usr/lib64']:
+ output += arg+' '
+
+ print(output)
-libs = getvar('LIBS').split() + getvar('SYSLIBS').split()
-if (hasattr(sys,'abiflags')):
- libs.append('-lpython' + pyver + sys.abiflags)
else:
- libs.append('-lpython' + pyver)
+ # DUPLICATE of "python-config --ldflags", fixed for the library location
+ # This proved to work gracefully up to Python 3.5 (exact limit unclear)
+
+ # This utility is known to work with:
+ # python2.6 (system install) under SL6.4
+ # python2.7 (custom install) under SL6.4
+ # python3.4 (custom install) under SL6.4
+ # python3.7 (custom install) under Debian12
+ # python2.7 (system install) under Fedora20
+ # python2.7 (Apple install) under MacOSX
+ # python2.7 (MacPorts install) under MacOSX
+ # python3.4 (MacPorts install) under MacOSX
+
+ import sys
+ import sysconfig
+
+ pyver = sysconfig.get_config_var('VERSION')
+ getvar = sysconfig.get_config_var
+
+ libs = getvar('LIBS').split() + getvar('SYSLIBS').split()
+ if (hasattr(sys,'abiflags')):
+ libs.append('-lpython' + pyver + sys.abiflags)
+ else:
+ libs.append('-lpython' + pyver)
-# Add the library path, except /usr/lib* which causes troubles
-# on the link command line, as it basically overrides all other
-# custom paths coming after it. No need to put these paths on
-# command line, they are found implicitly by the linker.
-ldpath = getvar('LIBDIR')
-if ldpath not in ['/usr/lib','/usr/lib32','/usr/lib64']:
- libs.insert(0, '-L' + getvar('LIBDIR'))
+ # Add the library path, except /usr/lib* which causes troubles
+ # on the link command line, as it basically overrides all other
+ # custom paths coming after it. No need to put these paths on
+ # command line, they are found implicitly by the linker.
+ ldpath = getvar('LIBDIR')
+ if ldpath not in ['/usr/lib','/usr/lib32','/usr/lib64']:
+ libs.insert(0, '-L' + getvar('LIBDIR'))
-# Framework (specific for Mac)
-if not getvar('PYTHONFRAMEWORK'):
- libs.extend(getvar('LINKFORSHARED').split())
+ # Framework (specific for Mac)
+ if not getvar('PYTHONFRAMEWORK'):
+ libs.extend(getvar('LINKFORSHARED').split())
-print(' '.join(libs))
+ print(' '.join(libs))

View File

@@ -31,6 +31,7 @@
perl,
pixman,
vips,
buildPackages,
sourcesJSON ? ./sources.json,
}:
let
@@ -38,6 +39,62 @@ let
sources = lib.importJSON sourcesJSON;
inherit (sources) version;
esbuild_0_23 = buildPackages.esbuild.override {
buildGoModule =
args:
buildPackages.buildGoModule (
args
// rec {
version = "0.23.0";
src = fetchFromGitHub {
owner = "evanw";
repo = "esbuild";
tag = "v${version}";
hash = "sha256-AH4Y5ELPicAdJZY5CBf2byOxTzOyQFRh4XoqRUQiAQw=";
};
vendorHash = "sha256-+BfxCyg0KkDQpHt/wycy/8CTG6YBA/VJvJFhhzUnSiQ=";
}
);
};
esbuild_0_25 = buildPackages.esbuild.override {
buildGoModule =
args:
buildPackages.buildGoModule (
args
// rec {
version = "0.25.2";
src = fetchFromGitHub {
owner = "evanw";
repo = "esbuild";
tag = "v${version}";
hash = "sha256-aDxheDMeQYqCT9XO3In6RbmzmXVchn+bjgf3nL3VE4I=";
};
vendorHash = "sha256-+BfxCyg0KkDQpHt/wycy/8CTG6YBA/VJvJFhhzUnSiQ=";
}
);
};
# Immich server does not actually need esbuild, but react-email and vite do.
# As esbuild doesn't support passing multiple binaries, we use a custom
# "shim", that picks the right version depending on the working directory.
# The correct version can be looked up in package-lock.json
# TODO: There are numerous other env vars this *could* be based on.
esbuildShim = buildPackages.writeShellScriptBin "esbuild" ''
echo "nixpkgs: esbuild shim for '$PWD'" >&2
case "$PWD" in
"/build/server/node_modules/esbuild")
exec ${lib.getExe esbuild_0_23} "$@"
;;
"/build/server/node_modules/vite/node_modules/esbuild")
exec ${lib.getExe esbuild_0_25} "$@"
exit 0
;;
esac
echo "nixpkgs: Couldn't resolve esbuild version for '$PWD'" >&2
exit 1
'';
buildLock = {
sources =
builtins.map
@@ -206,6 +263,7 @@ buildNpmPackage' {
makeCacheWritable = true;
env.SHARP_FORCE_GLOBAL_LIBVIPS = 1;
env.ESBUILD_BINARY_PATH = lib.getExe esbuildShim;
preBuild = ''
# If exiftool-vendored.pl isn't found, exiftool is searched for on the PATH

View File

@@ -1,15 +1,15 @@
{
"version": "3.2.13",
"version": "3.3.12",
"x86_64-linux": {
"url": "https://github.com/laurent22/joplin/releases/download/v3.2.13/Joplin-3.2.13.AppImage",
"sha256": "06xmm2annf3i8qfi8hclac3lgfssb2f3sx06vgabgsn67i8gid20"
"url": "https://github.com/laurent22/joplin/releases/download/v3.3.12/Joplin-3.3.12.AppImage",
"sha256": "1fjrblmlpm6sf4jdvifmyxic0rw2bs1f4sbw3nz4xy7wlsab5f62"
},
"x86_64-darwin": {
"url": "https://github.com/laurent22/joplin/releases/download/v3.2.13/Joplin-3.2.13.dmg",
"sha256": "1z9lp07z85jf1g2rwzn4q5kssfqqb921lfqgkjkjnz12padf3kpf"
"url": "https://github.com/laurent22/joplin/releases/download/v3.3.12/Joplin-3.3.12.dmg",
"sha256": "0rk5jl7i7sj31336r8yn8wf9h4xwdwi66wvwrkblvxrfhgddn2gj"
},
"aarch64-darwin": {
"url": "https://github.com/laurent22/joplin/releases/download/v3.2.13/Joplin-3.2.13-arm64.dmg",
"sha256": "0r7rfka60vrynwxdfk71mbhdwxv2rivxqc2qpzrhmz26h8vksm3h"
"url": "https://github.com/laurent22/joplin/releases/download/v3.3.12/Joplin-3.3.12-arm64.dmg",
"sha256": "13m4nypg1v5d7i13has9f1sp08dijc44962dr75b9jfiq8q6ciz6"
}
}

View File

@@ -9,11 +9,11 @@
stdenvNoCC.mkDerivation rec {
pname = "komga";
version = "1.21.2";
version = "1.21.3";
src = fetchurl {
url = "https://github.com/gotson/${pname}/releases/download/${version}/${pname}-${version}.jar";
sha256 = "sha256-FYw519VT40PU3fVEb7DBoST2bqhPXcEqquHkGeULQ3k=";
sha256 = "sha256-NFj/C1oNRh9PzAi5TUv+4vVea1Nsn/frxf4aZjuYfvA=";
};
nativeBuildInputs = [

View File

@@ -8,12 +8,12 @@
python3Packages.buildPythonApplication rec {
pname = "latexminted";
version = "0.5.1";
version = "0.6.0";
pyproject = true;
src = fetchPypi {
inherit pname version;
hash = "sha256-II3n7DtgTyuE2PMygJrmRW8uBRpnnoz2NXDMw20o8oo=";
hash = "sha256-WpYo9Ci3rshuVdsbAv4Hjx8vT2FLRinhNsVrcGoPXyU=";
};
build-system = with python3Packages; [

View File

@@ -174,11 +174,11 @@ in
stdenv.mkDerivation (finalAttrs: {
pname = "microsoft-edge";
version = "135.0.3179.85";
version = "136.0.3240.76";
src = fetchurl {
url = "https://packages.microsoft.com/repos/edge/pool/main/m/microsoft-edge-stable/microsoft-edge-stable_${finalAttrs.version}-1_amd64.deb";
hash = "sha256-x1YpKsvj2Jx1/VE13eE/aCkv+b7rGOQo4xcRYu2GQGA=";
hash = "sha256-biNM1exJ/xUcmhZjH7ZcFF9cYVqsPavbbtsJnRVlyFo=";
};
# With strictDeps on, some shebangs were not being patched correctly
@@ -284,7 +284,6 @@ stdenv.mkDerivation (finalAttrs: {
license = lib.licenses.unfree;
mainProgram = "microsoft-edge";
maintainers = with lib.maintainers; [
zanculmarktum
kuwii
rhysmdnz
];

View File

@@ -0,0 +1,43 @@
{
lib,
rustPlatform,
fetchCrate,
pkg-config,
openssl,
versionCheckHook,
}:
rustPlatform.buildRustPackage (finalAttrs: {
pname = "mini-redis";
version = "0.4.1";
src = fetchCrate {
inherit (finalAttrs) pname version;
sha256 = "sha256-vYphaQNMAHajod5oT/T3VJ12e6Qk5QOa5LQz6KsXvm8=";
};
cargoHash = "sha256-oGyJxNzJX7PwMkDoT9Tb3xF0vWgQwuyIjKPgEkbPKyI=";
nativeBuildInputs = [
pkg-config
];
buildInputs = [
openssl
];
nativeInstallCheckInputs = [
versionCheckHook
];
doInstallCheck = true;
versionCheckProgram = "${placeholder "out"}/bin/${finalAttrs.meta.mainProgram}";
doCheck = false;
meta = {
description = "Incomplete, idiomatic implementation of a Redis client and server built with Tokio, for learning purposes";
homepage = "https://github.com/tokio-rs/mini-redis";
license = lib.licenses.mit;
maintainers = with lib.maintainers; [ nomaterials ];
mainProgram = "mini-redis-cli";
};
})

View File

@@ -11,13 +11,13 @@
stdenv.mkDerivation (finalAttrs: {
pname = "msolve";
version = "0.7.5";
version = "0.8.0";
src = fetchFromGitHub {
owner = "algebraic-solving";
repo = "msolve";
tag = "v${finalAttrs.version}";
hash = "sha256-3AP3qrFZX2JZveONtmG0CLpdwSCwlrW86D8QLRTW5kI=";
hash = "sha256-0kqRnBJA5CwsLY/YWZXu2+y4aiZAQQYl30Qb3JX3zEo=";
};
postPatch = ''

View File

@@ -6,16 +6,16 @@
buildGoModule (finalAttrs: {
pname = "opencode";
version = "0.0.34";
version = "0.0.46";
src = fetchFromGitHub {
owner = "opencode-ai";
repo = "opencode";
tag = "v${finalAttrs.version}";
hash = "sha256-EaspkL0TEBJEUU3f75EhZ4BOIvbneUKnTNeNGhJdjYE=";
hash = "sha256-Q7ArUsFMpe0zayUMBJd+fC1K4jTGElIFep31Qa/L1jY=";
};
vendorHash = "sha256-cFzkMunPkGQDFhQ4NQZixc5z7JCGNI7eXBn826rWEvk=";
vendorHash = "sha256-MVpluFTF/2S6tRQQAXE3ujskQZ3njBkfve0RQgk3IkQ=";
checkFlags =
let

View File

@@ -7,13 +7,13 @@
buildGoModule rec {
pname = "orchard";
version = "0.33.0";
version = "0.33.2";
src = fetchFromGitHub {
owner = "cirruslabs";
repo = pname;
rev = version;
hash = "sha256-cOg7wwcwmpDNqnu15j5aYxLNpBxrhliK6w3sw2JQlCg=";
hash = "sha256-yiCMnP73C5MJLYjnZfqcKtdSzPyL/9WlAtylMXDl4E8=";
# populate values that require us to use git. By doing this in postFetch we
# can delete .git afterwards and maintain better reproducibility of the src.
leaveDotGit = true;
@@ -24,7 +24,7 @@ buildGoModule rec {
'';
};
vendorHash = "sha256-60GjN9jeYjGdkVxm+lNBS0OYt523c/HrfBPrvdET0hQ=";
vendorHash = "sha256-fU2TXUtcXmjswlEbSsbCTOaC5rvtctHbTKbR7zIwP/g=";
nativeBuildInputs = [ installShellFiles ];

View File

@@ -11,13 +11,13 @@
stdenv.mkDerivation (finalAttrs: {
pname = "paho.mqtt.cpp";
version = "1.5.2";
version = "1.5.3";
src = fetchFromGitHub {
owner = "eclipse";
repo = "paho.mqtt.cpp";
tag = "v${finalAttrs.version}";
hash = "sha256-3fUqtYFerjEmwn68rNvDeqGU+gly6fkWOyBPikhoFNg=";
hash = "sha256-vwfWcJqAWY4Em4MxZVcvOi6pzXAYYlOrKh6peMtjcXo=";
};
nativeBuildInputs = [ cmake ];

View File

@@ -10,16 +10,16 @@
buildNpmPackage rec {
pname = "pocket-casts";
version = "0.10.2";
version = "0.10.3";
src = fetchFromGitHub {
owner = "felicianotech";
repo = "pocket-casts-desktop-app";
rev = "v${version}";
hash = "sha256-qXwLnAp8GxOBnPy5uM/Y4dKlALRLo9Hs2p8/WSJcAyE=";
hash = "sha256-IhH5nZ2kXVW2D8cMmVyMX4xZLnzfMAp2gwQgZgHOItY=";
};
npmDepsHash = "sha256-HU+jfp+Rmw78wTSA0m9Q6EW6+bw84+MEnnSaPnKqqIo=";
npmDepsHash = "sha256-oLZ81SA+eO20sUc2cwba3cc6vu1Qf/lNkIfzK2CQdrw=";
env.ELECTRON_SKIP_BINARY_DOWNLOAD = "1";

View File

@@ -7,16 +7,16 @@
buildGoModule rec {
pname = "pocketbase";
version = "0.27.2";
version = "0.28.1";
src = fetchFromGitHub {
owner = "pocketbase";
repo = "pocketbase";
rev = "v${version}";
hash = "sha256-KvKBx5AKpcvgdf8tq2sJPLF63Fpa9KN3j5WJumR28k4=";
hash = "sha256-tx9dx4ZFmdllG/pMoI8mmPSvMg7fBk6+lXSxkW5jlDM=";
};
vendorHash = "sha256-1Qym5XRyMBfn5csp+YFkKNhJokDrHbfnpKAMq09Da5s=";
vendorHash = "sha256-DN3rCuRBFVeRfiXrwxeHemqOZgXb7OswwzcEqHbi4lo=";
# This is the released subpackage from upstream repo
subPackages = [ "examples/base" ];

View File

@@ -10,17 +10,17 @@
rustPlatform.buildRustPackage rec {
pname = "proto";
version = "0.48.1";
version = "0.49.1";
src = fetchFromGitHub {
owner = "moonrepo";
repo = "proto";
rev = "v${version}";
hash = "sha256-4ikjpr1IRULLpWC8sseWuF20YXUuCfdCP6VU/VgGWzE=";
hash = "sha256-VtU59YvNqpHvZ1WRj87Heo8RDyCOzleB+odE4DOQYag=";
};
useFetchCargoVendor = true;
cargoHash = "sha256-aa4fL33B4kAZx7A6XRvwLlUHsyZve5WOZBnGCWtfqFU=";
cargoHash = "sha256-wPB4YBNzDg9eoVCY4bbbvKu171Qdh7JJZIT9rD5hVdI=";
buildInputs = lib.optionals stdenv.hostPlatform.isDarwin [
libiconv

View File

@@ -72,7 +72,6 @@ rustPlatform.buildRustPackage {
];
maintainers = with lib.maintainers; [
detroyejr
uncenter
];
};
}

View File

@@ -8,11 +8,11 @@
stdenv.mkDerivation (finalAttrs: {
pname = "quarkus-cli";
version = "3.21.4";
version = "3.22.2";
src = fetchurl {
url = "https://github.com/quarkusio/quarkus/releases/download/${finalAttrs.version}/quarkus-cli-${finalAttrs.version}.tar.gz";
hash = "sha256-ksI55x1rmpIRfNNgajmAvprKU3OwL4EW8QpNV2eyPTc=";
hash = "sha256-RCWkaPoE3Purq9VG1xhlakMxqXhnxi+q10YcgOyScqg=";
};
nativeBuildInputs = [ makeWrapper ];

View File

@@ -16,7 +16,7 @@
stdenv,
}:
let
version = "2.49.1525";
version = "2.51.1534";
urlVersion = builtins.replaceStrings [ "." ] [ "0" ] version;
in
stdenv.mkDerivation {
@@ -25,7 +25,7 @@ stdenv.mkDerivation {
src = fetchurl {
url = "https://download.roonlabs.com/updates/production/RoonServer_linuxx64_${urlVersion}.tar.bz2";
hash = "sha256-DYxybP7luRmR4HL6QYBeWU4ZWqlHEO2EgLeqxmFD87A=";
hash = "sha256-x9zbWJ4lrqfC1CPquGsdgzhO3WBzd46dlZy6APqJbcg=";
};
dontConfigure = true;

View File

@@ -69,37 +69,45 @@ rustPlatform.buildRustPackage rec {
useFetchCargoVendor = true;
cargoRoot = "app/${app-type}/src-tauri";
buildAndTestSubdir = cargoRoot;
cargoPatches = [ ./remove-duplicate-versions-of-sys-metrics.patch ];
cargoPatches = [
./remove-duplicate-versions-of-sys-metrics.patch
./remove-code-signing-darwin.patch
];
cargoHash = app-type-either "sha256-XfN+/oC3lttDquLfoyJWBaFfdjW/wyODCIiZZksypLM=" "sha256-4vBHxuKg4P9H0FZYYNUT+AVj4Qvz99q7Bhd7x47UC2w=";
nativeBuildInputs = [
proper-cargo-tauri.hook
nativeBuildInputs =
[
proper-cargo-tauri.hook
# Setup pnpm
nodejs
pnpm_9.configHook
# Setup pnpm
nodejs
pnpm_9.configHook
# Make sure we can find our libraries
perl
pkg-config
protobuf
wrapGAppsHook4
];
# Make sure we can find our libraries
perl
pkg-config
protobuf
]
++ lib.optionals stdenv.hostPlatform.isLinux [
wrapGAppsHook4
];
buildInputs =
[ openssl ]
++ lib.optionals stdenv.hostPlatform.isLinux [
glib-networking
libayatana-appindicator
]
++ lib.optionals (app-type == "main") [
webkitgtk_4_1
libsoup_3
]
++ lib.optionals (app-type == "legacy") [
webkitgtk_4_0
libsoup_2_4
];
++ lib.optionals stdenv.hostPlatform.isLinux (
[
glib-networking
libayatana-appindicator
]
++ lib.optionals (app-type == "main") [
webkitgtk_4_1
libsoup_3
]
++ lib.optionals (app-type == "legacy") [
webkitgtk_4_0
libsoup_2_4
]
);
passthru =
# Don't set an update script for the legacy version

View File

@@ -0,0 +1,12 @@